#
# spec file for package python-Sphinx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-Sphinx%{psuffix}
Version:        7.3.7
Release:        1.1
Summary:        Python documentation generator
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://www.sphinx-doc.org
Source:         https://files.pythonhosted.org/packages/source/s/sphinx/sphinx-%{version}.tar.gz
# Provide intersphinx inventory offline, run update-intersphinx.sh
# https://docs.python.org/3/objects.inv
Source2:        python3.inv
# https://requests.readthedocs.io/en/stable/objects.inv
Source3:        requests.inv
# https://docs.readthedocs.io/en/stable/objects.inv
Source4:        readthedocs.inv
Source5:        update-intersphinx.sh
Source99:       python-Sphinx.keyring
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
# workaround for suboptimal CentOS-7 project config
#!BuildIgnore:  texinfo
Requires:       python-Babel >= 1.3
Requires:       python-Jinja2 >= 2.3
Requires:       python-Pygments >= 2.14
Requires:       python-alabaster >= 0.7
Requires:       python-defusedxml >= 0.7.1
Requires:       python-docutils >= 0.12
Requires:       python-imagesize
Requires:       python-packaging
Requires:       python-requests >= 2.5.0
Requires:       python-snowballstemmer >= 1.1
Requires:       python-sphinx_rtd_theme
Requires:       python-sphinxcontrib-applehelp
Requires:       python-sphinxcontrib-devhelp
Requires:       python-sphinxcontrib-htmlhelp >= 2.0.0
Requires:       python-sphinxcontrib-jsmath
Requires:       python-sphinxcontrib-qthelp >= 1.0.2
Requires:       python-sphinxcontrib-serializinghtml >= 1.1.9
Requires:       python-sphinxcontrib-websupport
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-SQLAlchemy >= 0.9
Recommends:     python-Sphinx-doc-man
Recommends:     python-Whoosh >= 2.0
BuildArch:      noarch
%if 0%{?python_version_nodots} < 310
Requires:       python-importlib-metadata >= 4.4
%endif
%if %{with test}
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module Sphinx = %{version}}
BuildRequires:  %{python_module Sphinx-latex = %{version}}
BuildRequires:  %{python_module defusedxml >= 0.7.1}
BuildRequires:  %{python_module filelock}
BuildRequires:  %{python_module html5lib}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinxcontrib-websupport}
BuildRequires:  %{python_module testsuite}
BuildRequires:  ImageMagick
BuildRequires:  graphviz
# For PNG format
BuildRequires:  graphviz-gd
# For PDF format (!?)
BuildRequires:  graphviz-gnome
BuildRequires:  texlive-tex-gyre
%endif
%python_subpackages

%description
Sphinx is a tool that facilitates creating documentation for Python
projects (or other documents consisting of multiple reStructuredText
sources). It was originally created for the Python documentation, and
supports Python project documentation well, but C/C++ is likewise
supported.

Sphinx uses reStructuredText as its markup language. Sphinx draws from
the parsing and translating suite, the Docutils.

%package latex
Summary:        Sphinx packages for LaTeX
Group:          Productivity/Publishing/TeX/Base
Requires:       python-Sphinx = %{version}
Requires:       texlive-dvipng
Requires:       texlive-gnu-freefont
Requires:       texlive-latex
Requires:       texlive-latexmk
Requires:       texlive-makeindex
Requires:       texlive-metafont
Requires:       texlive-pdftex
Requires:       tex(8r.enc)
Requires:       tex(alltt.sty)
Requires:       tex(amsfonts.sty)
Requires:       tex(amsmath.sty)
Requires:       tex(amssymb.sty)
Requires:       tex(amsthm.sty)
Requires:       tex(anyfontsize.sty)
Requires:       tex(array.sty)
Requires:       tex(article.cls)
Requires:       tex(atbegshi.sty)
Requires:       tex(babel.sty)
Requires:       tex(bm.sty)
Requires:       tex(capt-of.sty)
Requires:       tex(cmap.sty)
Requires:       tex(color.sty)
Requires:       tex(colortbl.sty)
Requires:       tex(dvipdfmx.def)
Requires:       tex(english.ldf)
Requires:       tex(eqparbox.sty)
Requires:       tex(fancybox.sty)
Requires:       tex(fancyhdr.sty)
Requires:       tex(fancyvrb.sty)
Requires:       tex(float.sty)
Requires:       tex(fncychap.sty)
Requires:       tex(fontenc.sty)
Requires:       tex(footnote.sty)
Requires:       tex(framed.sty)
Requires:       tex(graphics.sty)
Requires:       tex(graphicx.sty)
Requires:       tex(hypcap.sty)
Requires:       tex(hyperref.sty)
Requires:       tex(ifthen.sty)
Requires:       tex(inputenc.sty)
Requires:       tex(longtable.sty)
Requires:       tex(luatex85.sty)
Requires:       tex(makeidx.sty)
Requires:       tex(multirow.sty)
Requires:       tex(needspace.sty)
Requires:       tex(newfloat.sty)
Requires:       tex(palatino.sty)
Requires:       tex(parskip.sty)
Requires:       tex(pcrr.tfm)
Requires:       tex(pdftex.def)
Requires:       tex(pdftex.map)
Requires:       tex(phvr.tfm)
Requires:       tex(polyglossia.sty)
Requires:       tex(pplr.tfm)
Requires:       tex(preview.sty)
Requires:       tex(ptmr.tfm)
Requires:       tex(pzcmi.tfm)
Requires:       tex(tabulary.sty)
Requires:       tex(textcomp.sty)
Requires:       tex(tgtermes.sty)
Requires:       tex(threeparttable.sty)
Requires:       tex(times.sty)
Requires:       tex(titlesec.sty)
Requires:       tex(upquote.sty)
Requires:       tex(utf8.def)
Requires:       tex(utf8x.def)
Requires:       tex(varwidth.sty)
Requires:       tex(wrapfig.sty)

%description    latex
Sphinx is a tool that facilitates creating documentation for Python
projects (or other documents consisting of multiple reStructuredText
sources).

This package contains the LaTeX components for python-Sphinx.

%if 0%{?suse_version} > 1500
%package -n python-Sphinx-doc
Summary:        Man files for python-Sphinx
Group:          Documentation/Other
Requires:       python3-Sphinx = %{version}

%description -n python-Sphinx-doc
Sphinx is a tool that facilitates creating documentation for Python
projects (or other documents consisting of multiple reStructuredText
sources). It was originally created for the Python documentation, and
supports Python project documentation well, but C/C++ is likewise
supported.

Sphinx uses reStructuredText as its markup language. Sphinx draws from
the parsing and translating suite, the Docutils.

This package contains the documentation for Sphinx.

%package -n python-Sphinx-doc-man
Summary:        Man files for python-Sphinx
Group:          Documentation/Man
Requires:       python3-Sphinx = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
Supplements:    python3-Sphinx
Obsoletes:      python-Sphinx-doc-man-common <= %{version}

%description -n python-Sphinx-doc-man
Sphinx is a tool that facilitates creating documentation for Python
projects (or other documents consisting of multiple reStructuredText
sources).

This package contains the manual pages for the Sphinx executables.

%package -n python-Sphinx-doc-html
Summary:        HTML Documentation for python-Sphinx
Group:          Documentation/HTML
Provides:       python-Sphinx-doc-html = %{version}

%description -n python-Sphinx-doc-html
Sphinx is a tool that facilitates creating documentation for Python
projects (or other documents consisting of multiple reStructuredText
sources).

This package contains the HTML documentation for Sphinx.
%endif

%prep
%setup -q -n sphinx-%{version}
%autopatch -p1

%build
%pyproject_wheel

%if %{with test}
mkdir build.doc

cp %{SOURCE2} doc/python3.inv
cp %{SOURCE3} doc/requests.inv
cp %{SOURCE4} doc/readthedocs.inv
%{python_expand # Use one bundled intersphinx inventory for all flavors.
# The python3.6 inventory fails to build even in its own flavor.
# Use a more recent default (currently 3.9) from the source tag instead.
# The same for requests.
sed -i -e "s/\((.https:..docs.python.org.3.., \)None\()\)/\1'python3.inv'\2/g" doc/conf.py
sed -i -e "s/\((.https:..requests.readthedocs.io.*, \)None\()\)/\1'requests.inv'\2/g" doc/conf.py
sed -i -e "s/\((.https:..docs.readthedocs.io.*, \)None\()\)/\1'readthedocs.inv'\2/g" doc/conf.py
# rm build/sphinx/html/.buildinfo
$python -m sphinx -b man -j auto ./doc ./build.doc/man
$python -m sphinx -b html -j auto ./doc ./build.doc/html
}
%endif

%install
%if ! %{with test}
%pyproject_install

%python_clone -a %{buildroot}%{_bindir}/sphinx-apidoc
%python_clone -a %{buildroot}%{_bindir}/sphinx-autogen
%python_clone -a %{buildroot}%{_bindir}/sphinx-build
%python_clone -a %{buildroot}%{_bindir}/sphinx-quickstart

%python_expand mkdir -p %{buildroot}%{$python_sitelib}/sphinxcontrib
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# gh#openSUSE/python-rpm-macros#74
%{!?python_find_lang: %define python_find_lang() \
%find_lang %{**} \
langfile=%{?2}%{!?2:%1.lang} \
%{python_expand # \
grep -v 'python.*site-packages' ${langfile} > %{$python_prefix}-${langfile} \
grep -F %{$python_sitelib} ${langfile} >> %{$python_prefix}-${langfile} \
} \
}
%python_find_lang sphinx

%else
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_docdir}/python-Sphinx/
mv build.doc/html %{buildroot}%{_docdir}/python-Sphinx/
rm -rf %{buildroot}%{_docdir}/python-Sphinx/html/_images

mkdir -p %{buildroot}%{_mandir}/man1
mv build.doc/man/sphinx-all.1 %{buildroot}%{_mandir}/man1/sphinx-all.1
mv build.doc/man/sphinx-apidoc.1 %{buildroot}%{_mandir}/man1/sphinx-apidoc.1
mv build.doc/man/sphinx-build.1 %{buildroot}%{_mandir}/man1/sphinx-build.1
mv build.doc/man/sphinx-quickstart.1 %{buildroot}%{_mandir}/man1/sphinx-quickstart.1
%endif
%endif

# Always deduplicate
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if ! %{with test}
%post
%python_install_alternative sphinx-apidoc sphinx-autogen sphinx-build sphinx-quickstart
:

%postun
%python_uninstall_alternative sphinx-apidoc
%endif

%check
%if %{with test}
export PYTHONPATH=.
export LC_ALL="C.utf8"
# test_latex_images test downloading a remote image
# test_signature_annotations doesn’t work
%pytest tests -k 'not (linkcheck or test_latex_images or test_signature_annotations or test_copy_images or test_ext_imgconverter)'
%endif

%if ! %{with test}
%files %{python_files} -f %{python_prefix}-sphinx.lang
%license LICENSE.rst
%doc CHANGES.rst README.rst
%python_alternative %{_bindir}/sphinx-apidoc
%python_alternative %{_bindir}/sphinx-autogen
%python_alternative %{_bindir}/sphinx-build
%python_alternative %{_bindir}/sphinx-quickstart
%{python_sitelib}/sphinx/
%exclude %{python_sitelib}/sphinx/texinputs/
%dir %{python_sitelib}/sphinx-%{version}.dist-info
%{python_sitelib}/sphinx-%{version}.dist-info/*
%dir %{python_sitelib}/sphinxcontrib

%files %{python_files latex}
%license LICENSE.rst
%{python_sitelib}/sphinx/texinputs/
%endif

%if %{with test}
%if 0%{?suse_version} > 1500
%files -n python-Sphinx-doc-man
%license LICENSE.rst
%{_mandir}/man1/sphinx-all.1%{?ext_man}
%{_mandir}/man1/sphinx-apidoc.1%{?ext_man}
%{_mandir}/man1/sphinx-build.1%{?ext_man}
%{_mandir}/man1/sphinx-quickstart.1%{?ext_man}

%files -n python-Sphinx-doc-html
%license LICENSE.rst
%dir %{_docdir}/python-Sphinx/
%{_docdir}/python-Sphinx/html/
%endif
%endif

%changelog
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 7.3.7:
  * #12299: Defer loading themes defined via entry points until
    their explicit use by the user or a child theme. Patch by
    Adam Turner.
  * #12305: Return the default value for theme.get_config() with
    an unsupported theme configuration section. Patch by Adam
    Turner.
  * #12295: Re-export all AST types in the C and C++ domains.
    Patch by Adam Turner.
  * #12295: Re-export various objects from
    sphinx.domains.python._annotations in sphinx.domains.python.
    Patch by Jacob Chesslo and Adam Turner.
  * #12295: Re-export various objects from
    sphinx.domains.python._object in sphinx.domains.python. Patch
    by Jacob Chesslo and Adam Turner.
  * Handle cases when Any is not an instance of type. Patch by
    Adam Turner.
  * #12290: Fix a false-positive warning when setting a
    configuration value with Any as the valid type to a type
    other than the value's default. Patch by Adam Turner.
  * Preload all themes defined via entry points. Patch by Adam
    Turner.
  * Fix a bad interaction between the 'Furo' theme and the new-
    style for configuration values. Patch by Adam Turner.
  * Require tomli on Python 3.10 and earlier. Patch by Adam
    Turner.
  * #11858: Increase the minimum supported version of Alabaster
    to 0.7.14. Patch by Adam Turner.
  * #11411: Support Docutils 0.21. Patch by Adam Turner.
  * #12012: Use types-docutils instead of docutils-stubs.
  * #11693: Support for old-style :file:`Makefile` and
    :file:`make.bat` output in :program:`sphinx-quickstart`, and
    the associated options :option:`!-M`, :option:`!-m`,
    :option:`!--no-use-make-mode`, and :option:`!--use-make-
    mode`.
  * #11285: Direct access to
    :attr:`!sphinx.testing.util.SphinxTestApp._status` or
    :attr:`!sphinx.testing.util.SphinxTestApp._warning` is
    deprecated. Use the public properties
    :attr:`!sphinx.testing.util.SphinxTestApp.status` and
    :attr:`!sphinx.testing.util.SphinxTestApp.warning` instead.
    Patch by Bénédikt Tran.
  * tests: :func:`!sphinx.testing.util.strip_escseq` is
    deprecated in favour of
    :func:`!sphinx.util.console.strip_colors`. Patch by Bénédikt
    Tran.
  * #12265: Support theme configuration via theme.toml.
  * #11701: HTML Search: Adopt the new <search> element. Patch by
    Bénédikt Tran.
  * #11776: Add long option names to sphinx-build. Patch by Hugo
    van Kemenade, Adam Turner, Bénédikt Tran, and Ezio Melotti.
  * Organise the sphinx-build options into groups. Patch by Adam
    Turner.
  * #11855: Defer computation of configuration values. Patch by
    Adam Turner.
  * Add :no-search: as an alias of the :nosearch: metadata field.
    Patch by Adam Turner.
  * #11803: autodoc: Use an overriden __repr__() function in an
    enum, if defined. Patch by Shengyu Zhang.
  * #11825: Allow custom targets in the manpage role. Patch by
    Nicolas Peugnet.
  * #11892: Improved performance when resolving cross references
    in the C++ domain. Patch by Rouslan Korneychuk.
  * #11905: Add a :rst:dir:`versionremoved` directive. Patch by
    Hugo van Kemenade, Adam Turner, and C.A.M. Gerlach.
  * #11981: Improve rendering of signatures using slice syntax,
    e.g., def foo(arg: np.float64[:,:]) -> None: ....
  * The manpage builder now adds OSC 8 anchors to hyperlinks,
    using the groff device control command.
  * #11015: Change the text of the :rst:dir:`versionadded`
    directive from New in [...] to Added in [...]. Patch by
    Bénédikt Tran.
  * #12131: Added :confval:`show_warning_types` configuration
    option. Patch by Chris Sewell.
  * #12193: Improve external warnings for unknown roles. In
    particular, suggest related role names if an object type is
    mistakenly used. Patch by Chris Sewell.
  * Add public type alias
    :class:`sphinx.util.typing.ExtensionMetadata`. This can be
    used by extension developers to annotate the return type of
    their setup function. Patch by Chris Sewell.
  * #11668: Raise a useful error when theme.conf is missing.
    Patch by Vinay Sajip.
  * #11622: Ensure that the order of keys in searchindex.js is
    deterministic. Patch by Pietro Albini.
  * #11617: ANSI control sequences are stripped from the output
    when writing to a warnings file with :option:`-w <sphinx-
    build -w>`. Patch by Bénédikt Tran.
  * #11666: Skip all hidden directories in
    CatalogRepository.pofiles. Patch by Aryaz Eghbali.
  * #9686: html builder: Fix MathJax lazy loading when equations
    appear in titles. Patch by Bénédikt Tran.
  * #11483: singlehtml builder: Fix MathJax lazy loading when the
    index does not contain any math equations. Patch by Bénédikt
    Tran.
  * #11697: HTML Search: add 'noindex' meta robots tag. Patch by
    James Addison.
  * #11678: Fix a possible ZeroDivisionError in
    sphinx.ext.coverage. Patch by Stephen Finucane.
  * #11756: LaTeX: build error with recent TeXLive due to missing
    substitutefont package (triggered if using fontenc with T2A
    option and document language is not a Cyrillic one). Patch by
    Jean-François B.
  * #11675: Fix rendering of progression bars in environments
    that do not support ANSI control sequences. Patch by Bénédikt
    Tran.
  * #11861: Whitelist more types with an incorrect __module__
    attribute. Patch by Adam Turner.
  * #11715: Apply tls_verify and tls_cacerts config to
    ImageDownloader. Patch by Nick Touran.
  * Allow hyphens in group names for :rst:dir:`productionlist`
    cross-references. Patch by Adam Turner.
  * #11433: Added the :confval:`linkcheck_allow_unauthorized`
    configuration option. Set this option to False to report HTTP
    401 (unauthorized) server responses as broken. Patch by James
    Addison.
  * #11868: linkcheck: added a distinct timeout reporting status
    code. This can be enabled by setting
    :confval:`linkcheck_report_timeouts_as_broken` to False.
    Patch by James Addison.
  * #11869: Refresh the documentation for the linkcheck_timeout
    setting. Patch by James Addison.
  * #11874: Configure a default 30-second value for
    linkcheck_timeout. Patch by James Addison.
  * #11886: Print the Jinja2 template path chain in
    TemplateNotFound exceptions. Patch by Colin Marquardt.
  * #11598: Do not use query components in URLs for assets in
    EPUB rendering. Patch by David Runge.
  * #11904: Support unary subtraction when parsing annotations.
    Patch by James Addison.
  * #11925: Blacklist the sphinxprettysearchresults extension;
    the functionality it provides was merged into Sphinx v2.0.0.
    Patch by James Addison.
  * #11917: Fix rendering of annotated inherited members for
    Python 3.9. Patch by Janet Carson.
  * #11935: C Domain: Fix namespace-pop context. Patch by Frank
    Dana.
  * #11923: Avoid zombie processes when parallel builds fail.
    Patch by Felix von Drigalski.
  * #11353: Support enumeration classes inheriting from mixin or
    data types. Patch by Bénédikt Tran.
  * #11962: Fix target resolution when using :paramtype: fields.
    Patch by Bénédikt Tran.
  * #11944: Use anchor in search preview. Patch by Will Lachance.
  * #12008: Fix case-sensitive lookup of std:label names in
    intersphinx inventory. Patch by Michael Goerz.
  * #11958: HTML Search: Fix partial matches overwriting full
    matches. Patch by William Lachance.
  * #11959: Fix multiple term matching when word appears in both
    title and document. Patch by Will Lachance.
  * #11474: Fix doctrees caching causing files not be rebuilt in
    some cases, e.g., when :confval:`numfig` is True. Patch by
    Bénédikt Tran.
  * #11278: autodoc: Fix rendering of
    :class:`functools.singledispatchmethod` combined with
    :func:`@classmethod <classmethod>`. Patch by Bénédikt Tran.
  * #11894: Do not add checksums to css files if building using
    the htmlhelp builder. Patch by reduerK akiM.
  * #12052: Remove <script> and <style> tags from the content of
    search result summary snippets. Patch by James Addison.
  * #11578: HTML Search: Order non-main index entries after other
    results. Patch by Brad King.
  * #12147: autosummary: Fix a bug whereby the wrong file
    extension may be used, when multiple suffixes are specified
    in :confval:`source_suffix`. Patch by Sutou Kouhei.
  * #10786: improve the error message when a file to be copied
    (e.g., an asset) is removed during Sphinx execution. Patch by
    Bénédikt Tran.
  * #12040: HTML Search: Ensure that document titles that are
    partially-matched by the user search query are included in
    search results. Patch by James Addison.
  * #11970: singlehtml builder: make target URIs to be same-
    document references in the sense of :rfc:`RFC 3986, §4.4
    <3986#section-4.4>`, e.g., index.html#foo becomes #foo. Patch
    by Eric Norige.
  * #12271: Partially revert Docutils' r9562 to fix EPUB files.
    Patch by Adam Turner.
  * #12253: Escape reserved path characters in the remote images
    post-transform download cache. Patch by James Addison and
    Adam Turner.
  * Reorganise tests into directories. Patch by Adam Turner.
  * Clean up global state in SphinxTestApp. Patch by Adam Turner.
  * #11285: :func:`!pytest.mark.sphinx` and
    :class:`!sphinx.testing.util.SphinxTestApp` accept
    warningiserror, keep_going and verbosity as keyword
    arguments. Patch by Bénédikt Tran.
  * #11285: :class:`!sphinx.testing.util.SphinxTestApp` status
    and warning arguments are checked to be :class:`io.StringIO`
    objects (the public API incorrectly assumed this without
    checking it). Patch by Bénédikt Tran.
  * Report the result of test_run_epubcheck as skipped instead of
    success when either Java or epubcheck are not available.
  * Use dynamic allocation of unused port numbers for the test
    HTTP(S) servers. As a side-effect, this removes the need for
    test server lockfiles, meaning that any remaining tests/test-
    server.lock files can safely be deleted.
- drop fix-autodoc-tests-python-3117.patch,
  fix-test-expectation-for-enum-rendering-on-python-3.12.3.patch:
  upstream
* Mon Apr 22 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-test-expectation-for-enum-rendering-on-python-3.12.3.patch
  gh#sphinx-doc/sphinx#12293, bsc#1223128
* Wed Feb 28 2024 Ana Guerrero <ana.guerrero@suse.com>
- Disable test test_ext_imgconverter.
* Wed Dec 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add upstream patch fix-autodoc-tests-python-3117.patch to make it
  work with python 3.11.7 gh#sphinx-doc/sphinx#11793
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- avoid xdist - not used by upstream and unstable (and not
  improving the build time by more than 25%%)
* Fri Dec  1 2023 Dirk Müller <dmueller@suse.com>
- remove setuptools requires
* Thu Sep 14 2023 Dirk Müller <dmueller@suse.com>
- update to 7.2.6:
  * #11679: Add the :envvar:`!SPHINX_AUTODOC_RELOAD_MODULES`
    environment variable, which if set reloads modules when
    using autodoc with ``TYPE_CHECKING = True``.
  * #11679: Use :py:func:`importlib.reload` to reload modules in
    autodoc.
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 7.2.5:
  * #11645: Fix a regression preventing autodoc from importing
    modules within packages that make use of
    ``if typing.TYPE_CHECKING:`` to guard circular imports
    needed by type checkers.
  * #11634: Fixed inheritance diagram relative link resolution
    for sibling files in a subdirectory.
  * #11659: Allow ``?config=...`` in :confval:`mathjax_path`.
  * #11654: autodoc: Fail with a more descriptive error message
    when an object claims to be an instance of ``type``,
    but is not a class.
  * 11620: Cease emitting :event:`source-read` events for files
    read via the :dudir:`include` directive.
  * 11620: Add a new :event:`include-read` for observing and
    transforming the content of included files via the :dudir:`include`
    directive.
  * #11627: Restore support for copyright lines of the form
    ``YYYY`` when ``SOURCE_DATE_EPOCH`` is set.
* Wed Aug 30 2023 Markéta Machová <mmachova@suse.com>
- update to 7.2.4
  * Require sphinxcontrib-serializinghtml 1.1.9.
  * Fix regression in autodoc.Documenter.parse_name().
  * Fix regression in JSON serialisation.
  * autodoc: Support positional-only parameters in classmethod methods
    when autodoc_preserve_defaults is True.
  * Restore support string methods on path objects. This is deprecated
    and will be removed in Sphinx 8. Use os.fspath() to convert Path
    objects to strings, or Path’s methods to work with path objects.
  * Fix a regression in the MoveModuleTargets transform.
  * linkcheck: Resolve hanging tests for timezones west of London and
    incorrect conversion from UTC to offsets from the UNIX epoch.
* Wed Aug 23 2023 Markéta Machová <mmachova@suse.com>
- update to 7.2.2
  * Drop Python 3.8 support.
  * Require Pygments 2.14 or later.
  * Deprecate sphinx.util.md5 and sphinx.util.sha1. Use hashlib instead.
  * Deprecate sphinx.testing.path. Use os.path or pathlib instead.
  * Support os.PathLike types and pathlib.Path objects in many more places.
  * Add the :no-typesetting: option to suppress textual output and only
    create a linkable anchor.
  * Allow running Sphinx with python -m sphinx build
  * graphviz: Fix relative links from within the graph.
  * pytest: Fail tests on “XPASS”, Set PYTHONWARNINGS=error, set strict config
  * Restored the the str interface of the asset classes (_CascadingStyleSheet
    and _JavaScript), which several extensions relied upon. This will be
    removed in Sphinx 9.
  * Many more changes (even deprecations), see upstream changelog
* Mon Aug  7 2023 Dirk Müller <dmueller@suse.com>
- update to 7.1.2:
  * #11542: linkcheck: Properly respect :confval:`linkcheck_anchors`
    and do not spuriously report failures to validate anchors.
* Fri Jul 28 2023 Martin Liška <martin.liska@hey.com>
- Update to 7.1.1:
  * #11514: Fix ``SOURCE_DATE_EPOCH`` in multi-line copyright footer.
    Patch by Bénédikt Tran.
- Update to 7.1.0:
  * Releases are no longer signed, given the `change in PyPI policy`_.
  * #11412: Emit warnings on using a deprecated Python-specific index entry type
    (namely, ``module``, ``keyword``, ``operator``, ``object``, ``exception``,
    ``statement``, and ``builtin``) in the :rst:dir:`index` directive, and
    set the removal version to Sphinx 9. Patch by Adam Turner.
  * #11415: Add a checksum to JavaScript and CSS asset URIs included within
    generated HTML, using the CRC32 algorithm.
  * :meth:`~sphinx.application.Sphinx.require_sphinx` now allows the version
    requirement to be specified as ``(major, minor)``.
  * #11011: Allow configuring a line-length limit for object signatures, via
    :confval:`maximum_signature_line_length` and the domain-specific variants.
    If the length of the signature (in characters) is greater than the configured
    limit, each parameter in the signature will be split to its own logical line.
    This behaviour may also be controlled by options on object description
    directives, for example :rst:dir:`py:function:single-line-parameter-list`.
    Patch by Thomas Louf, Adam Turner, and Jean-François B.
  * #10983: Support for multiline copyright statements in the footer block.
    Patch by Stefanie Molin
  * ``sphinx.util.display.status_iterator`` now clears the current line
    with ANSI control codes, rather than overprinting with space characters.
  * #11431: linkcheck: Treat SSL failures as broken links.
    Patch by Bénédikt Tran
  * #11157: Keep the ``translated`` attribute on translated nodes.
  * #11451: Improve the traceback displayed when using :option:`sphinx-build -T`
    in parallel builds. Patch by Bénédikt Tran
  * #11324: linkcheck: Use session-basd HTTP requests.
  * #11438: Add support for the :rst:dir:`py:class` and :rst:dir:`py:function`
    directives for PEP 695 (generic classes and functions declarations) and
    PEP 696 (default type parameters).  Multi-line support (#11011) is enabled
    for type parameters list and can be locally controlled on object description
    directives, e.g., :rst:dir:`py:function:single-line-type-parameter-list`.
    Patch by Bénédikt Tran.
  * #11484: linkcheck: Allow HTML anchors to be ignored on a per-URL basis
    via :confval:`linkcheck_anchors_ignore_for_url` while
    still checking the validity of the page itself.
    Patch by Bénédikt Tran
  * #1246: Add translation progress statistics and inspection support,
    via a new substitution (``|translation progress|``) and a new
    configuration variable (:confval:`translation_progress_classes`).
    These enable determining the percentage of translated elements within
    a document, and the remaining translated and untranslated elements.
  * Restored the ``footnote-reference`` class that has been removed in
    the latest (unreleased) version of Docutils.
  * #11486: Use :rfc:`8081` font file MIME types in the EPUB builder.
    Using the correct MIME type will prevent warnings from ``epubcheck``
    and will generate a valid EPUB.
  * #11435: Use microsecond-resolution timestamps for outdated file detection
    in ``BuildEnvironment.get_outdated_files``.
  * #11437: Top-level headings starting with a reStructuredText role
    now render properly when :confval:`rst_prolog` is set.
    Previously, a file starting with the below would have
    improperly rendered due to where the prologue text
    was inserted into the document.
    Patch by Bénédikt Tran.
  * #11337: Fix a ``MemoryError`` in ``sphinx.ext.intersphinx`` when using ``None``
    or ``typing.*`` as inline type references. Patch by Bénédikt Tran (picnixz)
  * #11345: Always delete ``docutils.conf`` in test directories when running
    ``SphinxTestApp.cleanup()``.
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 7.0.1:
  * Support `Docutils 0.20`_.
  * #11418: Clean up remaining references to
    ``sphinx.setup_command``
    following the removal of support for setuptools.
* Sun Apr 30 2023 Martin Liška <mliska@suse.cz>
- Update to version 7.0.0
  * #11359: Remove long-deprecated aliases for ``MecabSplitter`` and
    ``DefaultSplitter`` in ``sphinx.search.ja``.
  * #11360: Remove deprecated ``make_old_id`` functions in domain object
    description classes.
  * #11363: Remove the Setuptools integration (``build_sphinx`` hook in
    ``setup.py``).
  * #11364: Remove deprecated ``sphinx.ext.napoleon.iterators`` module.
  * #11365: Remove support for the ``jsdump`` format in ``sphinx.search``.
  * #11366: Make ``locale`` a required argument to
    ``sphinx.util.i18n.format_date()``.
  * #11370: Remove deprecated ``sphinx.util.stemmer`` module.
  * #11371: Remove deprecated ``sphinx.pycode.ast.parse()`` function.
  * #11372: Remove deprecated ``sphinx.io.read_doc()`` function.
  * #11373: Removed deprecated ``sphinx.util.get_matching_files()`` function.
  * #11378: Remove deprecated ``sphinx.util.docutils.is_html5_writer_available()``
    function.
  * #11379: Make the ``env`` argument to ``Builder`` subclasses required.
  * #11380: autosummary: Always emit grouped import exceptions.
  * #11381: Remove deprecated ``style`` key for HTML templates.
  * #11382: Remove deprecated ``sphinx.writers.latex.LaTeXTranslator.docclasses``
    attribute.
  * #11383: Remove deprecated ``sphinx.builders.html.html5_ready`` and
    ``sphinx.builders.html.HTMLTranslator`` attributes.
  * #11385: Remove support for HTML 4 output.
* Wed Apr 26 2023 Matej Cepl <mcepl@suse.com>
- For PSP packages don't include documentation at all. The
  building of Sphinx documentation is so complicated, that it is
  not possible to include it in the main package.
* Tue Apr 25 2023 Martin Liška <mliska@suse.cz>
- Update to version 6.2.1
  * #11355: Revert the default type of :confval:`nitpick_ignore` and
    :confval:`nitpick_ignore_regex` to ``list``.
* Mon Apr 24 2023 Martin Liška <mliska@suse.cz>
- Bump to version 6.2.0
  * Require Docutils 0.18.1 or greater.
  * LaTeX: removal of some internal TeX ``\dimen`` registers (not previously
    publicly documented) as per 5.1.0 code comments in ``sphinx.sty``:
    ``\sphinxverbatimsep``, ``\sphinxverbatimborder``, ``\sphinxshadowsep``,
    ``\sphinxshadowsize``, and ``\sphinxshadowrule``. (refs: #11105)
  * Remove ``.egg`` support from pycode ``ModuleAnalyser``; Python eggs are a
    now-obsolete binary distribution format
  * #11089: Remove deprecated code in ``sphinx.builders.linkcheck``.
    Patch by Daniel Eades
  * Remove internal-only ``sphinx.locale.setlocale``
  * #11247: Deprecate the legacy ``intersphinx_mapping`` format
  * ``sphinx.util.osutil.cd`` is deprecated in favour of ``contextlib.chdir``.
  * #11277: :rst:dir:`autoproperty` allows the return type to be specified as
    a type comment (e.g., ``# type: () -> int``). Patch by Bénédikt Tran
  * #10811: Autosummary: extend ``__all__`` to imported members for template rendering
    when option ``autosummary_ignore_module_all`` is set to ``False``. Patch by
    Clement Pinard
  * #11147: Add a ``content_offset`` parameter to ``nested_parse_with_titles()``,
    allowing for correct line numbers during nested parsing.
    Patch by Jeremy Maitin-Shepard
  * Update to Unicode CLDR 42
  * Add a ``--jobs`` synonym for ``-j``. Patch by Hugo van Kemenade
  * LaTeX: a command ``\sphinxbox`` for styling text elements with a (possibly
    rounded) box, optional background color and shadow, has been added.
    See :ref:`sphinxbox`. (refs: #11224)
  * LaTeX: add ``\sphinxstylenotetitle``, ..., ``\sphinxstylewarningtitle``, ...,
    for an extra layer of mark-up freeing up ``\sphinxstrong`` for other uses.
    See :ref:`latex-macros`. (refs: #11267)
  * LaTeX: :dudir:`note`, :dudir:`hint`, :dudir:`important` and :dudir:`tip` can
    now each be styled as the other admonitions, i.e. possibly with a background
    color, individual border widths and paddings, possibly rounded corners, and
    optional shadow.  See :ref:`additionalcss`. (refs: #11234)
  * LaTeX: admonitions and :dudir:`topic` (and
    :dudir:`contents <table-of-contents>`) directives, and not only
    :rst:dir:`code-block`, support ``box-decoration-break=slice``.
  * LaTeX: let rounded boxes support up to 4 distinct border-widths (refs: #11243)
  * LaTeX: new options ``noteTextColor``, ``noteTeXextras`` et al.
    See :ref:`additionalcss`.
  * LaTeX: support elliptical corners in rounded boxes. (refs: #11254)
  * #11150: Include source location in highlighting warnings, when lexing fails.
    Patch by Jeremy Maitin-Shepard
  * #11281: Support for :confval:`imgmath_latex` ``= 'tectonic'`` or
    ``= 'xelatex'``.  Patch by Dimitar Dimitrov
  * #11109, #9643: Add :confval:`python_display_short_literal_types` option for
    condensed rendering of ``Literal`` types.
  * #11079: LaTeX: figures with align attribute may disappear and strangely impact
    following lists
  * #11093: LaTeX: fix "multiply-defined references" PDF build warnings when one or
    more reST labels directly precede an :rst:dir:`py:module` or :rst:dir:`automodule`
    directive. Patch by Bénédikt Tran (picnixz)
  * #11110: LaTeX: Figures go missing from latex pdf if their files have the same
    base name and they use a post transform.  Patch by aaron-cooper
  * LaTeX: fix potential color leak from shadow to border of rounded boxes, if
    shadow color is set but border color is not
  * LaTeX: fix unintended 1pt upwards vertical shift of code blocks frames
    respective to contents (when using rounded corners)
  * #11235: LaTeX: added ``\color`` in topic (or admonition) contents may cause color
    leak to the shadow and border at a page break
  * #11264: LaTeX: missing space before colon after "Voir aussi" for :rst:dir:`seealso`
    directive in French
  * #11268: LaTeX: longtable with left alignment breaks out of current list
    indentation context in PDF.  Thanks to picnixz.
  * #11274: LaTeX: external links are not properly escaped for ``\sphinxupquote``
    compatibility
  * #11147: Fix source file/line number info in object description content and in
    other uses of ``nested_parse_with_titles``.  Patch by Jeremy Maitin-Shepard.
  * #11192: Restore correct parallel search index building.
    Patch by Jeremy Maitin-Shepard
  * Use the new Transifex ``tx`` client
  * Fail testing when any Python warnings are emitted
  * Migrate remaining ``unittest.TestCase`` style test functions to pytest style
  * Remove tests that rely on setuptools
- Remove alabaster-0713-compat.patch upstreamed patch.
- Update intersphinx links.
- Install filelock python dependency for tests.
- Run tests parallel.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Jan 29 2023 Dirk Müller <dmueller@suse.com>
- add alabaster-0713-compat.patch to fix testsuite failure with
  newer alabaster theme.
* Tue Jan 10 2023 Martin Liška <mliska@suse.cz>
- Update to version 6.1.3
  * #11116: Reverted to previous Sphinx 5 node copying method
  * #11117: Reverted changes to parallel image processing from Sphinx 6.1.0
  * #11119: Supress ``ValueError`` in the ``linkcheck`` builder
* Sun Jan  8 2023 Martin Liška <mliska@suse.cz>
- Update to version 6.1.2
  * #11101: LaTeX: div.topic_padding key of sphinxsetup documented at 5.1.0 was
    implemented with name topic_padding
  * #11099: LaTeX: shadowrule key of sphinxsetup causes PDF build to crash since
    Sphinx 5.1.0
  * #11096: LaTeX: shadowsize key of sphinxsetup causes PDF build to crash since
    Sphinx 5.1.0
  * #11095: LaTeX: shadow of topic and contents boxes not in page margin since
    Sphinx 5.1.0
  * #11100: Fix copying images when running under parallel mode.
- Disable test_copy_images tests as they need an internet access.
* Thu Jan  5 2023 Martin Liška <mliska@suse.cz>
- Update to version 6.1.1
  * #11091: Fix ``util.nodes.apply_source_workaround`` for ``literal_block`` nodes
    with no source information in the node or the node's parents.
  * Adopted the `Ruff`_ code linter.
    .. _Ruff: https://github.com/charliermarsh/ruff
  * #10979: gettext: Removed support for pluralisation in ``get_translation``.
    This was unused and complicated other changes to ``sphinx.locale``.
  * ``sphinx.util`` functions:
  * Renamed ``sphinx.util.typing.stringify()``
    to ``sphinx.util.typing.stringify_annotation()``
  * Moved ``sphinx.util.xmlname_checker()``
    to ``sphinx.builders.epub3._XML_NAME_PATTERN``
    Moved to ``sphinx.util.display``:
  * ``sphinx.util.status_iterator``
  * ``sphinx.util.display_chunk``
  * ``sphinx.util.SkipProgressMessage``
  * ``sphinx.util.progress_message``
    Moved to ``sphinx.util.http_date``:
  * ``sphinx.util.epoch_to_rfc1123``
  * ``sphinx.util.rfc1123_to_epoch``
    Moved to ``sphinx.util.exceptions``:
  * ``sphinx.util.save_traceback``
  * ``sphinx.util.format_exception_cut_frames``
  * Cache doctrees in the build environment during the writing phase.
  * Make all writing phase tasks support parallel execution.
  * #11072: Use PEP 604 (``X | Y``) display conventions for ``typing.Optional``
    and ``typing.Optional`` types within the Python domain and autodoc.
  * #10700: autodoc: Document ``typing.NewType()`` types as classes rather than
    'data'.
  * Cache doctrees between the reading and writing phases.
  * #10962: HTML: Fix the multi-word key name lookup table.
  * Fixed support for Python 3.12 alpha 3 (changes in the ``enum`` module).
  * #11069: HTML Theme: Removed outdated "shortcut" link relation keyword.
  * #10952: Properly terminate parallel processes on programme interuption.
  * #10988: Speed up ``TocTree.resolve()`` through more efficient copying.
  * #6744: LaTeX: support for seealso directive should be via an environment
    to allow styling.
  * #11074: LaTeX: Can't change sphinxnote to use sphinxheavybox starting with
    5.1.0
  * Require Pygments 2.13 or later.
  * #10944: imgmath:  Fix resolving image paths for files in nested folders.
* Wed Jan  4 2023 Martin Liška <mliska@suse.cz>
- Add pygments-2.14.patch in order to fix Pygments tests
  after the 2.14 release.
  gh#sphinx-doc/sphinx#11067
* Sat Dec 31 2022 Martin Liška <mliska@suse.cz>
- Update to version 6.0.0
  * #10468: Drop Python 3.6 support
  * #10470: Drop Python 3.7, Docutils 0.14, Docutils 0.15, Docutils 0.16, and
    Docutils 0.17 support. Patch by Adam Turner
  * #7405: Removed the jQuery and underscore.js JavaScript frameworks.
    These frameworks are no longer be automatically injected into themes from
    Sphinx 6.0. If you develop a theme or extension that uses the
    ``jQuery``, ``$``, or ``$u`` global objects, you need to update your
    JavaScript to modern standards, or use the mitigation below.
    The first option is to use the sphinxcontrib.jquery_ extension, which has been
    developed by the Sphinx team and contributors. To use this, add
    ``sphinxcontrib.jquery`` to the ``extensions`` list in ``conf.py``, or call
    ``app.setup_extension("sphinxcontrib.jquery")`` if you develop a Sphinx theme
    or extension.
    The second option is to manually ensure that the frameworks are present.
    To re-add jQuery and underscore.js, you will need to copy ``jquery.js`` and
    ``underscore.js`` from `the Sphinx repository`_ to your ``static`` directory,
    and add the following to your ``layout.html``:
    .. code-block:: html+jinja
    {%%- block scripts %%}
    <script src="{{ pathto('_static/jquery.js', resource=True) }}"></script>
    <script src="{{ pathto('_static/underscore.js', resource=True) }}"></script>
    {{ super() }}
    {%%- endblock %%}
    .. _sphinxcontrib.jquery: https://github.com/sphinx-contrib/jquery/
    Patch by Adam Turner.
  * #10471, #10565: Removed deprecated APIs scheduled for removal in Sphinx 6.0. See
    :ref:`dev-deprecated-apis` for details. Patch by Adam Turner.
  * #10901: C Domain: Remove support for parsing pre-v3 style type directives and
    roles. Also remove associated configuration variables ``c_allow_pre_v3`` and
    ``c_warn_on_allowed_pre_v3``. Patch by Adam Turner.
  * #10924: LaTeX: adopt better looking defaults for tables and code-blocks.
    See :confval:`latex_table_style` and the ``pre_border-radius`` and
    ``pre_background-TeXcolor`` :ref:`additionalcss` for the former defaults
    and how to re-enact them if desired.
  * #10984: LaTeX: Document :confval:`latex_additional_files` behavior for files
    with ``.tex`` extension.
* Sun Oct 16 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.3.0
  * #10759: LaTeX: add :confval:`latex_table_style` and support the
    ``'booktabs'``, ``'borderless'``, and ``'colorrows'`` styles.
    (thanks to Stefan Wiehler for initial pull requests #6666, #6671)
  * #10840: One can cross-reference including an option value like ``:option:`--module=foobar```,
    ``:option:`--module[=foobar]``` or ``:option:`--module foobar```.
    Patch by Martin Liska.
  * #10881: autosectionlabel: Record the generated section label to the debug log.
  * #10268: Correctly URI-escape image filenames.
  * #10887: domains: Allow sections in all the content of all object description
    directives (e.g. :rst:dir:`py:function`). Patch by Adam Turner
* Sun Oct  2 2022 Markéta Machová <mmachova@suse.com>
- BuildRequires just flit-core instead of flit
* Fri Sep 30 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.2.3
  * #10878: Fix base64 image embedding in sphinx.ext.imgmath
  * #10886: Add :nocontentsentry: flag and global domain table of contents entry
    control option. Patch by Adam Turner
* Tue Sep 27 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.2.2
  * #10872: Restore link targets for autodoc modules to the top of content.
    Patch by Dominic Davis-Foster.
* Mon Sep 26 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.2.1
  * #10861: Always normalise the ``pycon3`` lexer to ``pycon``.
  * Fix using ``sphinx.ext.autosummary`` with modules containing titles in the
    module-level docstring.
- Remove unneeded spec hunks.
* Sun Sep 25 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.2.0
  * #10356: Sphinx now uses declarative metadata with pyproject.toml to create packages,
    using PyPA’s build project as a build backend. Patch by Adam Turner.
  * #10286: C++, support requires clauses not just between the template parameter lists and the declaration.
  * #10755: linkcheck: Check the source URL of raw directives that use the url option.
  * #10781: Allow ref role to be used with definitions and fields.
  * #10717: HTML Search: Increase priority for full title and subtitle matches in search results
  * #10718: HTML Search: Save search result score to the HTML element for debugging
  * #10673: Make toctree accept ‘genindex’, ‘modindex’ and ‘search’ docnames
  * #6316, #10804: Add domain objects to the table of contents. Patch by Adam Turner
  * #6692: HTML Search: Include explicit index directive index entries in the search index and search results. Patch by Adam Turner
  * #10816: imgmath: Allow embedding images in HTML as base64
  * #10257: C++, ensure consistent non-specialization template argument representation.
  * #10729: C++, fix parsing of certain non-type template parameter packs.
  * #10715: Revert #10520: “Fix” use of sidebar classes in agogo.css_t
* Wed Jul 27 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.1.1
  * #10701: Fix ValueError in the new ``deque`` based ``sphinx.ext.napolean``
    iterator implementation.
  * #10702: Restore compatability with third-party builders.
* Sun Jul 24 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.1.0
  * #10656: Support `Docutils 0.19`_. Patch by Adam Turner.
  * #10467: Deprecated ``sphinx.util.stemmer`` in favour of ``snowballstemmer``.
    Patch by Adam Turner.
  * #9856: Deprecated ``sphinx.ext.napoleon.iterators``.
  * #10444: html theme: Allow specifying multiple CSS files through the ``stylesheet``
    setting in ``theme.conf`` or by setting ``html_style`` to an iterable of strings.
  * #10366: std domain: Add support for emphasising placeholders in :rst:dir:`option`
    directives through a new :confval:`option_emphasise_placeholders` configuration
    option.
  * #10439: std domain: Use the repr of some variables when displaying warnings,
    making whitespace issues easier to identify.
  * #10571: quickstart: Reduce content in the generated ``conf.py`` file. Patch by
    Pradyun Gedam.
  * #10648: LaTeX: CSS-named-alike additional :ref:`'sphinxsetup' <latexsphinxsetup>`
    keys allow to configure four separate border-widths, four paddings, four
    corner radii, a shadow (possibly inset), colours for border, background, shadow
    for each of the code-block, topic, attention, caution, danger, error and warning
    directives.
  * #10655: LaTeX: Explain non-standard encoding in LatinRules.xdy
  * #10599: HTML Theme: Wrap consecutive footnotes in an ``<aside>`` element when
    using Docutils 0.18 or later, to allow for easier styling. This matches the
    behaviour introduced in Docutils 0.19. Patch by Adam Turner.
  * #10518: config: Add ``include_patterns`` as the opposite of ``exclude_patterns``.
    Patch by Adam Turner.
  * #10594: HTML Theme: field term colons are doubled if using Docutils 0.18+
  * #10596: Build failure if Docutils version is 0.18 (not 0.18.1) due
    to missing ``Node.findall()``
  * #10506: LaTeX: build error if highlighting inline code role in figure caption
    (refs: #10251)
  * #10634: Make -P (pdb) option work better with exceptions triggered from events
  * #10031: py domain: Fix spurious whitespace in unparsing various operators (``+``,
    ``-``, ``~``, and ``**``). Patch by Adam Turner.
  * #10460: logging: Always show node source locations as absolute paths.
  * HTML Search: HTML tags are displayed as a part of object name
  * HTML Search: search snipets should not be folded
  * HTML Search: Minor errors are emitted on fetching search snipets
  * HTML Search: The markers for header links are shown in the search result
  * #10520: HTML Theme: Fix use of sidebar classes in ``agogo.css_t``.
  * #6679: HTML Theme: Fix inclusion of hidden toctrees in the agogo theme.
  * #10566: HTML Theme: Fix enable_search_shortcuts does not work
  * #8686: LaTeX: Text can fall out of code-block at end of page and leave artifact
    on next page
  * #10633: LaTeX: user injected ``\color`` commands in topic or admonition boxes may
    cause color leaks in PDF due to upstream `framed.sty <https://ctan.org/pkg/framed>`_
    bug
  * #10638: LaTeX: framed coloured boxes in highlighted code (e.g. highlighted
    diffs using Pygments style ``'manni'``) inherit thickness of code-block frame
  * #10647: LaTeX: Only one ``\label`` is generated for ``desc_signature`` node
    even if it has multiple node IDs
  * #10579: i18n: UnboundLocalError is raised on translating raw directive
  * #9577, #10088: py domain: Fix warning for duplicate Python references when
    using ``:any:`` and autodoc.
  * #10548: HTML Search: fix minor summary issues.
- Add update-intersphinx.sh and get all objects.inv files.
- Add Adam Turner's GPG key (61F0FB52) to python-Sphinx.keyring.
* Tue Jul 19 2022 Matej Cepl <mcepl@suse.com>
- (bsc#1201272) Add a missing dependency of latex subpackage on
  tex(tgtermes.sty).
- Add python-Sphinx.keyring
* Fri Jun 17 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.0.2
  * #10523: HTML Theme: Expose the Docutils's version info tuple as a template
  variable, ``docutils_version_info``. Patch by Adam Turner.
  * #10538: autodoc: Inherited class attribute having docstring is documented even
  if :confval:`autodoc_inherit_docstring` is disabled
  * #10509: autosummary: autosummary fails with a shared library
  * #10497: py domain: Failed to resolve strings in Literal. Patch by Adam Turner.
  * #10523: HTML Theme: Fix double brackets on citation references in Docutils 0.18+.
  Patch by Adam Turner.
  * #10534: Missing CSS for nav.contents in Docutils 0.18+. Patch by Adam Turner.
* Fri Jun  3 2022 Michael Ströder <michael@stroeder.com>
- Update to version 5.0.1
  * #10498: gettext: TypeError is raised when sorting warning messages if a node
    has no line number
  * #10493: html theme: :rst:dir:`topic` directive is rendered incorrectly with
    docutils-0.18
  * #10495: IndexError is raised for a :rst:role:`kbd` role having a separator
* Mon May 30 2022 Martin Liška <mliska@suse.cz>
- Update to version 5.0.0:
  * #10164: Support `Docutils 0.18`_. Patch by Adam Turner.
  * #10031: autosummary: ``sphinx.ext.autosummary.import_by_name()`` now raises
    ``ImportExceptionGroup`` instead of ``ImportError`` when it failed to import
    target object.  Please handle the exception if your extension uses the
    function to import Python object.  As a workaround, you can disable the
    behavior via ``grouped_exception=False`` keyword argument until v7.0.
  * #9962: texinfo: Customizing styles of emphasized text via ``@definfoenclose``
    command was not supported because the command was deprecated since texinfo 6.8
  * #2068: :confval:`intersphinx_disabled_reftypes` has changed default value
    from an empty list to ``['std:doc']`` as avoid too surprising silent
    intersphinx resolutions.
    To migrate: either add an explicit inventory name to the references
    intersphinx should resolve, or explicitly set the value of this configuration
    variable to an empty list.
  * #10197: html theme: Reduce ``body_min_width`` setting in basic theme to 360px
  * #9999: LaTeX: separate terms from their definitions by a CR (refs: #9985)
  * #10062: Change the default language to ``'en'`` if any language is not set in
    ``conf.py``
  * #10474: :confval:`language` does not accept ``None`` as it value.  The default
    value of ``language`` becomes to ``'en'`` now.
  * #10028: jQuery and underscore.js will no longer be automatically injected into
    themes from Sphinx 6.0. If you develop a theme or extension that uses the
    ``jQuery``, ``$``, or ``$u`` global objects, you need to update your
    JavaScript or use the mitigation below.
    To re-add jQuery and underscore.js, you will need to copy ``jquery.js`` and
    ``underscore.js`` from `the Sphinx repository`_ to your ``static`` directory,
    and add the following to your ``layout.html``:
    .. _the Sphinx repository: https://github.com/sphinx-doc/sphinx/tree/v4.3.2/sphinx/themes/basic/static
    .. code-block:: html+jinja
    {%%- block scripts %%}
    <script src="{{ pathto('_static/jquery.js', resource=True) }}"></script>
    <script src="{{ pathto('_static/underscore.js', resource=True) }}"></script>
    {{ super() }}
    {%%- endblock %%}
  * setuptools integration.  The ``build_sphinx`` sub-command for setup.py is
    marked as deprecated to follow the policy of setuptools team.
  * The ``locale`` argument of ``sphinx.util.i18n:babel_format_date()`` becomes
    required
  * The ``language`` argument of ``sphinx.util.i18n:format_date()`` becomes
    required
  * ``sphinx.builders.html.html5_ready``
  * ``sphinx.io.read_doc()``
  * ``sphinx.util.docutils.__version_info__``
  * ``sphinx.util.docutils.is_html5_writer_available()``
  * ``sphinx.writers.latex.LaTeXWriter.docclasses``
  * #9075: autodoc: The default value of :confval:`autodoc_typehints_format` is
    changed to ``'smart'``.  It will suppress the leading module names of
    typehints (ex. ``io.StringIO`` -> ``StringIO``).
  * #8417: autodoc: ``:inherited-members:`` option now takes multiple classes.  It
    allows to suppress inherited members of several classes on the module at once
    by specifying the option to :rst:dir:`automodule` directive
  * #9792: autodoc: Add new option for ``autodoc_typehints_description_target`` to
    include undocumented return values but not undocumented parameters.
  * #10285: autodoc: singledispatch functions having typehints are not documented
  * autodoc: :confval:`autodoc_typehints_format` now also applies to attributes,
    data, properties, and type variable bounds.
  * #10258: autosummary: Recognize a documented attribute of a module as
    non-imported
  * #10028: Removed internal usages of JavaScript frameworks (jQuery and
    underscore.js) and modernised ``doctools.js`` and ``searchtools.js`` to
    EMCAScript 2018.
  * #10302: C++, add support for conditional expressions (``?:``).
  * #5157, #10251: Inline code is able to be highlighted via :rst:dir:`role`
    directive
  * #10337: Make sphinx-build faster by caching Publisher object during build
  * #10200: apidoc: Duplicated submodules are shown for modules having both .pyx
    and .so files
  * #10279: autodoc: Default values for keyword only arguments in overloaded
    functions are rendered as a string literal
  * #10280: autodoc: :confval:`autodoc_docstring_signature` unexpectedly generates
    return value typehint for constructors if docstring has multiple signatures
  * #10266: autodoc: :confval:`autodoc_preserve_defaults` does not work for
    mixture of keyword only arguments with/without defaults
  * #10310: autodoc: class methods are not documented when decorated with mocked
    function
  * #10305: autodoc: Failed to extract optional forward-ref'ed typehints correctly
    via :confval:`autodoc_type_aliases`
  * #10421: autodoc: :confval:`autodoc_preserve_defaults` doesn't work on class
    methods
  * #10214: html: invalid language tag was generated if :confval:`language`
    contains a country code (ex. zh_CN)
  * #9974: html: Updated jQuery version from 3.5.1 to 3.6.0
  * #10236: html search: objects are duplicated in search result
  * #9962: texinfo: Deprecation message for ``@definfoenclose`` command on
    bulding texinfo document
  * #10000: LaTeX: glossary terms with common definition are rendered with
    too much vertical whitespace
  * #10188: LaTeX: alternating multiply referred footnotes produce a ``?`` in
    pdf output
  * #10363: LaTeX: make ``'howto'`` title page rule use ``\linewidth`` for
    compatibility with usage of a ``twocolumn`` class option
  * #10318: ``:prepend:`` option of :rst:dir:`literalinclude` directive does not
    work with ``:dedent:`` option
  * #9575: autodoc: The annotation of return value should not be shown when
    ``autodoc_typehints="description"``
  * #9648: autodoc: ``*args`` and ``**kwargs`` entries are duplicated when
    ``autodoc_typehints="description"``
  * #8180: autodoc: Docstring metadata ignored for attributes
  * #10443: epub: EPUB builder can't detect the mimetype of .webp file
  * #10104: gettext: Duplicated locations are shown if 3rd party extension does
    not provide correct information
  * #10456: py domain: ``:meta:`` fields are displayed if docstring contains two
    or more meta-field
  * #9096: sphinx-build: the value of progress bar for paralle build is wrong
  * #10110: sphinx-build: exit code is not changed when error is raised on
    builder-finished event
* Mon Mar 28 2022 Martin Liška <mliska@suse.cz>
- Update to version 4.5.0:
  * #10112: extlinks: Disable hardcoded links detector by default
  * #9993, #10177: std domain: Disallow to refer an inline target via
    :rst:role:`ref` role
  * ``sphinx.ext.napoleon.docstring.GoogleDocstring._qualify_name()``
  * #10260: Enable ``FORCE_COLOR`` and ``NO_COLOR`` for terminal colouring
  * #10234: autosummary: Add "autosummary" CSS class to summary tables
  * #10125: extlinks: Improve suggestion message for a reference having title
  * #10112: extlinks: Add :confval:`extlinks_detect_hardcoded_links` to enable
    hardcoded links detector feature
  * #9494, #9456: html search: Add a config variable
    :confval:`html_show_search_summary` to enable/disable the search summaries
  * #9337: HTML theme, add option ``enable_search_shortcuts`` that enables :kbd:'/' as
    a Quick search shortcut and :kbd:`Esc` shortcut that
    removes search highlighting.
  * #10107: i18n: Allow to suppress translation warnings by adding ``#noqa``
    comment to the tail of each translation message
  * #10252: C++, support attributes on classes, unions, and enums.
  * #10253: :rst:dir:`pep` role now generates URLs based on peps.python.org
  * #9876: autodoc: Failed to document an imported class that is built from native
    binary module
  * #10133: autodoc: Crashed when mocked module is used for type annotation
  * #10146: autodoc: :confval:`autodoc_default_options` does not support
    ``no-value`` option
  * #9971: autodoc: TypeError is raised when the target object is annotated by
    unhashable object
  * #10205: extlinks: Failed to compile regexp on checking hardcoded links
  * #10277: html search: Could not search short words (ex. "use")
  * #9529: LaTeX: named auto numbered footnote (ex. ``[#named]``) that is referred
    multiple times was rendered to a question mark
  * #9924: LaTeX: multi-line :rst:dir:`cpp:function` directive has big vertical
    spacing in Latexpdf
  * #10158: LaTeX: excessive whitespace since v4.4.0 for undocumented
    variables/structure members
  * #10175: LaTeX: named footnote reference is linked to an incorrect footnote if
    the name is also used in the different document
  * #10269: manpage: Failed to resolve the title of :ref: cross references
  * #10179: i18n: suppress "rST localization" warning
  * #10118: imgconverter: Unnecessary availablity check is called for remote URIs
  * #10181: napoleon: attributes are displayed like class attributes for google
    style docstrings when :confval:`napoleon_use_ivar` is enabled
  * #10122: sphinx-build: make.bat does not check the installation of sphinx-build
    command before showing help
- Update url for requests.inv.
* Fri Jan 28 2022 Matej Cepl <mcepl@suse.com>
- SPEC cleanup
* Thu Jan 20 2022 Ben Greiner <code@bnavigator.de>
- Fix missing install_requires dependencies.
* Wed Jan 19 2022 Matej Cepl <mcepl@suse.com>
- I know it looks cool to have URLs for all Source files, but these are
  files in VCS and they are inherently very unstable, so it breaks our
  checks.
* Sun Jan 16 2022 Martin Liška <mliska@suse.cz>
- Update to version 4.4.0:
  * #10007: Use ``importlib_metadata`` for python-3.9 or older
  * #10007: Drop ``setuptools``
  * #9075: autodoc: Add a config variable :confval:`autodoc_typehints_format`
    to suppress the leading module names of typehints of function signatures (ex.
    ``io.StringIO`` -> ``StringIO``)
  * #9831: Autosummary now documents only the members specified in a module's
    ``__all__`` attribute if :confval:`autosummary_ignore_module_all` is set to
    ``False``. The default behaviour is unchanged. Autogen also now supports
    this behavior with the ``--respect-module-all`` switch.
  * #9555: autosummary: Improve error messages on failure to load target object
  * #9800: extlinks: Emit warning if a hardcoded link is replaceable
    by an extlink, suggesting a replacement.
  * #9961: html: Support nested <kbd> HTML elements in other HTML builders
  * #10013: html: Allow to change the loading method of JS via ``loading_method``
    parameter for :meth:`Sphinx.add_js_file()`
  * #9551: html search: "Hide Search Matches" link removes "highlight" parameter
    from URL
  * #9815: html theme: Wrap sidebar components in div to allow customizing their
    layout via CSS
  * #9827: i18n: Sort items in glossary by translated terms
  * #9899: py domain: Allows to specify cross-reference specifier (``.`` and
    ``~``) as ``:type:`` option
  * #9894: linkcheck: add option ``linkcheck_exclude_documents`` to disable link
    checking in matched documents.
  * #9793: sphinx-build: Allow to use the parallel build feature in macOS on macOS
    and Python3.8+
  * #10055: sphinx-build: Create directories when ``-w`` option given
  * #9993: std domain: Allow to refer an inline target (ex. ``_`target name```)
    via :rst:role:`ref` role
  * #9981: std domain: Strip value part of the option directive from general index
  * #9391: texinfo: improve variable in ``samp`` role
  * #9578: texinfo: Add :confval:`texinfo_cross_references` to disable cross
    references for readability with standalone readers
  * #9822 (and #9062), add new Intersphinx role :rst:role:`external` for explict
    lookup in the external projects, without resolving to the local project.
  * #9866: autodoc: doccomment for the imported class was ignored
  * #9883: autodoc: doccomment for the alias to mocked object was ignored
  * #9908: autodoc: debug message is shown on building document using NewTypes
    with Python 3.10
  * #9968: autodoc: instance variables are not shown if __init__ method has
    position-only-arguments
  * #9194: autodoc: types under the "typing" module are not hyperlinked
  * #10009: autodoc: Crashes if target object raises an error on getting docstring
  * #10058: autosummary: Imported members are not shown when
    ``autodoc_class_signature = 'separated'``
  * #9947: i18n: topic directive having a bullet list can't be translatable
  * #9878: mathjax: MathJax configuration is placed after loading MathJax itself
  * #9932: napoleon: empty "returns" section is generated even if no description
  * #9857: Generated RFC links use outdated base url
  * #9909: HTML, prevent line-wrapping in literal text.
  * #10061: html theme: Configuration values added by themes are not be able to
    override from conf.py
  * #10073: imgconverter: Unnecessary availablity check is called for "data" URIs
  * #9925: LaTeX: prohibit also with ``'xelatex'`` line splitting at dashes of
    inline and parsed literals
  * #9944: LaTeX: extra vertical whitespace for some nested declarations
  * #9940: LaTeX: Multi-function declaration in Python domain has cramped
    vertical spacing in latexpdf output
  * #10015: py domain: types under the "typing" module are not hyperlinked defined
    at info-field-list
  * #9390: texinfo: Do not emit labels inside footnotes
  * #9413: xml: Invalid XML was generated when cross referencing python objects
  * #9979: Error level messages were displayed as warning messages
  * #10057: Failed to scan documents if the project is placed onto the root
    directory
  * #9636: code-block: ``:dedent:`` without argument did strip newlines
- Add new intersphinx mapping file: readthedocs.inv.
- Fix %%fdupes.
- Remove python-Sphinx-rpmlintrc as it is not used any more.
* Wed Dec 22 2021 Martin Liška <mliska@suse.cz>
- Update to version 4.3.2:
  * #9917: C and C++, parse fundamental types no matter the order of simple type
    specifiers.
* Sat Nov 27 2021 Arun Persaud <arun@gmx.de>
- update to version 4.3.1:
  * Features added
    + #9864: mathjax: Support chnaging the loading method of MathJax
    to "defer" via :confval:`mathjax_options`
  * Bugs fixed
    + #9838: autodoc: AttributeError is raised on building document
    for functions decorated by functools.lru_cache
    + #9879: autodoc: AttributeError is raised on building document
    for an object having invalid __doc__ atribute
    + #9844: autodoc: Failed to process a function wrapped with
    functools.partial if :confval:`autodoc_preserve_defaults`
    enabled
    + #9872: html: Class namespace collision between autodoc
    signatures and docutils-0.17
    + #9868: imgmath: Crashed if the dvisvgm command failed to convert
    equation
    + #9864: mathjax: Failed to render equations via MathJax v2.  The
    loading method of MathJax is back to "async" method again
* Fri Nov 12 2021 Matej Cepl <mcepl@suse.com>
- Explicitly Require python-sphinxcontrib-qthelp >= 1.0.2 to prevent
  bsc#1157793 and bsc#1158158 from occuring.
* Fri Nov 12 2021 Martin Liška <mliska@suse.cz>
- Update rpmlintrc file.
- Update to 4.3.0:
  * Support Python 3.10
  * #9649: ``searchindex.js``: the embedded data has changed format to allow
    objects with the same name in different domains.
  * #9672: The rendering of Python domain declarations is implemented
    with more docutils nodes to allow better CSS styling.
    It may break existing styling.
  * #9672: the signature of
    :py:meth:`domains.py.PyObject.get_signature_prefix` has changed to
    return a list of nodes instead of a plain string.
  * #9695: ``domains.js.JSObject.display_prefix`` has been changed into a method
    ``get_display_prefix`` which now returns a list of nodes
    instead of a plain string.
  * #9695: The rendering of Javascript domain declarations is implemented
    with more docutils nodes to allow better CSS styling.
    It may break existing styling.
  * #9450: mathjax: Load MathJax via "defer" strategy
  * ``sphinx.ext.autodoc.AttributeDocumenter._datadescriptor``
  * ``sphinx.writers.html.HTMLTranslator._fieldlist_row_index``
  * ``sphinx.writers.html.HTMLTranslator._table_row_index``
  * ``sphinx.writers.html5.HTML5Translator._fieldlist_row_index``
  * ``sphinx.writers.html5.HTML5Translator._table_row_index``
  * #9639: autodoc: Support asynchronous generator functions
  * #9664: autodoc: ``autodoc-process-bases`` supports to inject reST snippet as a
    base class
  * #9691: C, added new info-field ``retval``
    for :rst:dir:`c:function` and :rst:dir:`c:macro`.
  * C++, added new info-field ``retval`` for :rst:dir:`cpp:function`.
  * #9618: i18n: Add :confval:`gettext_allow_fuzzy_translations` to allow "fuzzy"
    messages for translation
  * #9672: More CSS classes on Python domain descriptions
  * #9695: More CSS classes on Javascript domain descriptions
  * #9683: Revert the removal of ``add_stylesheet()`` API.  It will be kept until
    the Sphinx-6.0 release
  * #2068, add :confval:`intersphinx_disabled_reftypes` for disabling
    interphinx resolution of cross-references that do not have an explicit
    inventory specification. Specific types of cross-references can be disabled,
    e.g., ``std:doc`` or all cross-references in a specific domain,
    e.g., ``std:*``.
  * #9623: Allow to suppress "toctree contains reference to excluded document"
    warnings using :confval:`suppress_warnings`
  * #9630: autodoc: Failed to build cross references if :confval:`primary_domain`
    is not 'py'
  * #9644: autodoc: Crashed on getting source info from problematic object
  * #9655: autodoc: mocked object having doc comment is warned unexpectedly
  * #9651: autodoc: return type field is not generated even if
    :confval:`autodoc_typehints_description_target` is set to "documented" when
    its info-field-list contains ``:returns:`` field
  * #9657: autodoc: The base class for a subclass of mocked object is incorrect
  * #9607: autodoc: Incorrect base class detection for the subclasses of the
    generic class
  * #9755: autodoc: memory addresses are shown for aliases
  * #9752: autodoc: Failed to detect type annotation for slots attribute
  * #9756: autodoc: Crashed if classmethod does not have __func__ attribute
  * #9757: autodoc: :confval:`autodoc_inherit_docstrings` does not effect to
    overriden classmethods
  * #9781: autodoc: :confval:`autodoc_preserve_defaults` does not support
    hexadecimal numeric
  * #9630: autosummary: Failed to build summary table if :confval:`primary_domain`
    is not 'py'
  * #9670: html: Fix download file with special characters
  * #9710: html: Wrong styles for even/odd rows in nested tables
  * #9763: html: parameter name and its type annotation are not separated in HTML
  * #9649: HTML search: when objects have the same name but in different domains,
    return all of them as result instead of just one.
  * #7634: intersphinx: references on the file in sub directory are broken
  * #9737: LaTeX: hlist is rendered as a list containing "aggedright" text
  * #9678: linkcheck: file extension was shown twice in warnings
  * #9697: py domain: An index entry with parens was registered for ``py:method``
    directive with ``:property:`` option
  * #9775: py domain: Literal typehint was converted to a cross reference when
    :confval:`autodoc_typehints='description'`
  * #9708: needs_extension failed to check double-digit version correctly
  * #9688: Fix :rst:dir:`code`` does not recognize ``:class:`` option
  * #9733: Fix for logging handler flushing warnings in the middle of the docs
    build
  * #9656: Fix warnings without subtype being incorrectly suppressed
  * Intersphinx, for unresolved references with an explicit inventory,
    e.g., ``proj:myFunc``, leave the inventory prefix in the unresolved text.
* Wed Nov 10 2021 Matej Cepl <mcepl@suse.com>
- Fix Provides and Obsoletes ... we cannot use python_module there
* Tue Sep 14 2021 Martin Liška <mliska@suse.cz>
- Update to 4.2.0:
  * #9445: autodoc: Support class properties
  * #9479: autodoc: Emit a warning if target is a mocked object
  * #9560: autodoc: Allow to refer NewType instances with module name in Python
    3.10 or above
  * #9447: html theme: Expose the version of Sphinx in the form of tuple as a
    template variable ``sphinx_version_tuple``
  * #9594: manpage: Suppress the title of man page if description is empty
  * #9445: py domain: ``:py:property:`` directive supports ``:classmethod:``
    option to describe the class property
  * #9524: test: SphinxTestApp can take ``builddir`` as an argument
  * #9535: C and C++, support more fundamental types, including GNU extensions.
  * #9608: apidoc: apidoc does not generate a module definition for implicit
    namespace package
  * #9504: autodoc: generate incorrect reference to the parent class if the target
    class inherites the class having ``_name`` attribute
  * #9537, #9589: autodoc: Some objects under ``typing`` module are not displayed
    well with the HEAD of 3.10
  * #9487: autodoc: typehint for cached_property is not shown
  * #9509: autodoc: AttributeError is raised on failed resolving typehints
  * #9518: autodoc: autodoc_docstring_signature does not effect to ``__init__()``
    and ``__new__()``
  * #9522: autodoc: PEP 585 style typehints having arguments (ex. ``list[int]``)
    are not displayed well
  * #9481: autosummary: some warnings contain non-existing filenames
  * #9568: autosummary: summarise overlined sectioned headings correctly
  * #9600: autosummary: Type annotations which contain commas in autosummary table
    are not removed completely
  * #9481: c domain: some warnings contain non-existing filenames
  * #9481: cpp domain: some warnings contain non-existing filenames
  * #9456: html search: abbreation marks are inserted to the search result if
    failed to fetch the content of the page
  * #9617: html search: The JS requirement warning is shown if browser is slow
  * #9267: html theme: CSS and JS files added by theme were loaded twice
  * #9585: py domain: ``:type:`` option for :rst:dir:`py:property` directive does
    not create a hyperlink
  * #9576: py domain: Literal typehint was converted to a cross reference
  * #9535 comment: C++, fix parsing of defaulted function parameters that are
    function pointers.
  * #9564: smartquotes: don't adjust typography for text with
    language-highlighted ``:code:`` role.
  * #9512: sphinx-build: crashed with the HEAD of Python 3.10
* Sun Aug  1 2021 Dirk Müller <dmueller@suse.com>
- update to 4.1.2:
  * linkcheck: Disable checking automatically generated anchors on
    github.com (ex. anchors in reST/Markdown documents)
  * autodoc: Custom types using ``typing.NewType`` are not displayed well
    with the HEAD of 3.10
  * autodoc: Some objects under ``typing`` module are not displayed well
    with the HEAD of 3.10
  * autodoc: crashed if ``autodoc_class_signature = "separated"``
  * html search: html_copy_source can't control the search summaries
  * linkcheck: Failed to check anchors in github.com
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  * sphinxcontrib-htmlhelp-2.0.0 or above
  * sphinxcontrib-serializinghtml-1.1.5 or above
  * html: HTML logo or Favicon specified as file not being found on output
* Mon Jul 12 2021 Martin Liška <mliska@suse.cz>
- Bump to 4.1.0:
  * Support jinja2-3.0
  * The ``app`` argument of ``sphinx.environment.BuildEnvironment`` becomes
    required
  * ``sphinx.application.Sphinx.html_theme``
  * ``sphinx.ext.autosummary._app``
  * ``sphinx.util.docstrings.extract_metadata()``
  * #8107: autodoc: Add ``class-doc-from`` option to :rst:dir:`autoclass`
    directive to control the content of the specific class like
    :confval:`autoclass_content`
  * #8588: autodoc: :confval:`autodoc_type_aliases` now supports dotted name. It
    allows you to define an alias for a class with module name like
    ``foo.bar.BazClass``
  * #9175: autodoc: Special member is not documented in the module
  * #9195: autodoc: The arguments of ``typing.Literal`` are wrongly rendered
  * #9185: autodoc: :confval:`autodoc_typehints` allows ``'both'`` setting to
    allow typehints to be included both in the signature and description
  * #4257: autodoc: Add :confval:`autodoc_class_signature` to separate the class
    entry and the definition of ``__init__()`` method
  * #8061, #9218: autodoc: Support variable comment for alias classes
  * #3014: autodoc: Add :event:`autodoc-process-bases` to modify the base classes
    of the class definitions
  * #9272: autodoc: Render enum values for the default argument value better
  * #9384: autodoc: ``autodoc_typehints='none'`` now erases typehints for
    variables, attributes and properties
  * #3257: autosummary: Support instance attributes for classes
  * #9358: html: Add "heading" role to the toctree items
  * #9225: html: Add span tag to the return typehint of method/function
  * #9129: html search: Show search summaries when html_copy_source = False
  * #9307: html search: Prevent corrections and completions in search field
  * #9120: html theme: Eliminate prompt characters of code-block from copyable
    text
  * #9176: i18n: Emit a debug message if message catalog file not found under
    :confval:`locale_dirs`
  * #9414: LaTeX: Add xeCJKVerbAddon to default fvset config for Chinese documents
  * #9016: linkcheck: Support checking anchors on github.com
  * #9016: linkcheck: Add a new event :event:`linkcheck-process-uri` to modify
    URIs before checking hyperlinks
  * #6525: linkcheck: Add :confval:`linkcheck_allowed_redirects` to mark
    hyperlinks that are redirected to expected URLs as "working"
  * #1874: py domain: Support union types using ``|`` in info-field-list
  * #9268: py domain: :confval:`python_use_unqualified_type_names` supports type
    field in info-field-list
  * #9097: Optimize the parallel build
  * #9131: Add :confval:`nitpick_ignore_regex` to ignore nitpicky warnings using
    regular expressions
  * #9174: Add ``Sphinx.set_html_assets_policy`` to tell extensions to include
    HTML assets in all the pages. Extensions can check this via
    ``Sphinx.registry.html_assets_policy``
  * C++, add support for
  - ``inline`` variables,
  - ``consteval`` functions,
  - ``constinit`` variables,
  - ``char8_t``,
  - ``explicit(<constant expression>)`` specifier,
  - digit separators in literals, and
  - constraints in placeholder type specifiers, aka. adjective syntax
    (e.g., ``Sortable auto &v``).
  * C, add support for digit separators in literals.
  * #9166: LaTeX: support containers in LaTeX output
  * #8872: autodoc: stacked singledispatches are wrongly rendered
  * #8597: autodoc: a docsting having metadata only should be treated as
    undocumented
  * #9185: autodoc: typehints for overloaded functions and methods are inaccurate
  * #9250: autodoc: The inherited method not having docstring is wrongly parsed
  * #9283: autodoc: autoattribute directive failed to generate document for an
    attribute not having any comment
  * #9364: autodoc: single element tuple on the default argument value is wrongly
    rendered
  * #9362: autodoc: AttributeError is raised on processing a subclass of Tuple[()]
  * #9404: autodoc: TypeError is raised on processing dict-like object (not a
    class) via autoclass directive
  * #9317: html: Pushing left key causes visiting the next page at the first page
  * #9381: html: URL for html_favicon and html_log does not work
  * #9270: html theme : pyramid theme generates incorrect logo links
  * #9217: manpage: The name of manpage directory that is generated by
    :confval:`man_make_section_directory` is not correct
  * #9350: manpage: Fix font isn't reset after keyword at the top of samp role
  * #9306: Linkcheck reports broken link when remote server closes the connection
    on HEAD request
  * #9280: py domain: "exceptions" module is not displayed
  * #9418: py domain: a Callable annotation with no parameters
    (e.g. ``Callable[[], None])`` will be rendered with a bracket missing
    (``Callable[], None]``)
  * #9319: quickstart: Make sphinx-quickstart exit when conf.py already exists
  * #9387: xml: XML Builder ignores custom visitors
  * #9224: ``:param:`` and ``:type:`` fields does not support a type containing
    whitespace (ex. ``Dict[str, str]``)
  * #8945: when transforming typed fields, call the specified role instead of
    making an single xref. For C and C++, use the ``expr`` role for typed fields.
* Sat Jun  5 2021 Martin Liška <mliska@suse.cz>
- Update again to 4.0.2.
* Wed Jun  2 2021 Matej Cepl <mcepl@suse.com>
- Switch off the failing test_signature_annotations. It is just
  not worthy filing upstream test on the obsolete version.
* Wed Jun  2 2021 Matej Cepl <mcepl@suse.com>
- Revert to 3.5.4
* Fri May 21 2021 Martin Liška <mliska@suse.cz>
- Update to 4.0.2: see upstream CHANGES.
- Add texlive-tex-gyre build dependency for tests.
* Fri Apr 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.5.4:
  * #9071: Restrict docutils to 0.16
  * #9078: autodoc: Async staticmethods and classmethods are considered as non
    async coroutine-functions with Python3.10
  * #8870, #9001, #9051: html theme: The style are not applied with docutils-0.17
* Tue Apr  6 2021 Dirk Müller <dmueller@suse.com>
- update to 3.5.3:
  * #8959: using UNIX path separator in image directive confuses Sphinx on Windows
* Tue Mar 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.5.2:
  * #8943: i18n: Crashed by broken translation messages in ES, EL and HR
  * #8936: LaTeX: A custom LaTeX builder fails with unknown node error
  * #8952: Exceptions raised in a Directive cause parallel builds to hang
  * #8883: autodoc: AttributeError is raised on assigning __annotations__ on
    read-only class
  * #8884: html: minified js stemmers not included in the distributed package
  * #8885: html: AttributeError is raised if CSS/JS files are installed via
    :confval:`html_context`
  * #8880: viewcode: ExtensionError is raised on incremental build after
    unparsable python module found
  * LaTeX: ``multicol`` (it is anyhow a required part of the official latex2e
    base distribution)
  * Update Underscore.js to 1.12.0
  * #6550: html: The config variable ``html_add_permalinks`` is replaced by
    :confval:`html_permalinks` and :confval:`html_permalinks_icon`
  * pending_xref node for viewcode extension
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.anchors_ignore``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.auth``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.broken``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.good``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.redirected``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.rqueue``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.to_ignore``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.workers``
  * ``sphinx.builders.linkcheck.CheckExternalLinksBuilder.wqueue``
  * ``sphinx.builders.linkcheck.node_line_or_0()``
  * ``sphinx.ext.autodoc.AttributeDocumenter.isinstanceattribute()``
  * ``sphinx.ext.autodoc.directive.DocumenterBridge.reporter``
  * ``sphinx.ext.autodoc.importer.get_module_members()``
  * ``sphinx.ext.autosummary.generate._simple_info()``
  * ``sphinx.ext.autosummary.generate._simple_warn()``
  * ``sphinx.writers.html.HTMLTranslator.permalink_text``
  * ``sphinx.writers.html5.HTML5Translator.permalink_text``
  * #8022: autodoc: autodata and autoattribute directives does not show right-hand
    value of the variable if docstring contains ``:meta hide-value:`` in
    info-field-list
  * #8514: autodoc: Default values of overloaded functions are taken from actual
    implementation if they're ellipsis
  * #8775: autodoc: Support type union operator (PEP-604) in Python 3.10 or above
  * #8297: autodoc: Allow to extend :confval:`autodoc_default_options` via
    directive options
  * #8619: html: kbd role generates customizable HTML tags for compound keys
  * #8634: html: Allow to change the order of JS/CSS via ``priority`` parameter
    for :meth:`Sphinx.add_js_file()` and :meth:`Sphinx.add_css_file()`
  * #6241: html: Allow to add JS/CSS files to the specific page when an extension
    calls ``app.add_js_file()`` or ``app.add_css_file()`` on
    :event:`html-page-context` event
  * #6550: html: Allow to use HTML permalink texts via
    :confval:`html_permalinks_icon`
  * #1638: html: Add permalink icons to glossary terms
  * #8868: html search: performance issue with massive lists
  * #8867: html search: Update JavaScript stemmer code to the latest version of
    Snowball (v2.1.0)
  * #8852: i18n: Allow to translate heading syntax in MyST-Parser
  * #8649: imgconverter: Skip availability check if builder supports the image
    type
  * #8573: napoleon: Allow to change the style of custom sections using
    :confval:`napoleon_custom_styles`
  * #8004: napoleon: Type definitions in Google style docstrings are rendered as
    references when :confval:`napoleon_preprocess_types` enabled
  * #6241: mathjax: Include mathjax.js only on the document using equations
  * #8775: py domain: Support type union operator (PEP-604)
  * #8651: std domain: cross-reference for a rubric having inline item is broken
  * #7642: std domain: Optimize case-insensitive match of term
  * #8681: viewcode: Support incremental build
  * #8132: Add :confval:`project_copyright` as an alias of :confval:`copyright`
  * #207: Now :confval:`highlight_language` supports multiple languages
  * #2030: :rst:dir:`code-block` and :rst:dir:`literalinclude` supports automatic
    dedent via no-argument ``:dedent:`` option
  * C++, also hyperlink operator overloads in expressions and alias declarations.
  * #8247: Allow production lists to refer to tokens from other production groups
  * #8813: Show what extension (or module) caused it on errors on event handler
  * #8213: C++: add ``maxdepth`` option to :rst:dir:`cpp:alias` to insert nested
    declarations.
  * C, add ``noroot`` option to :rst:dir:`c:alias` to render only nested
    declarations.
  * C++, add ``noroot`` option to :rst:dir:`cpp:alias` to render only nested
    declarations.
  * #8727: apidoc: namespace module file is not generated if no submodules there
  * #741: autodoc: inherited-members doesn't work for instance attributes on super
    class
  * #8592: autodoc: ``:meta public:`` does not effect to variables
  * #8594: autodoc: empty __all__ attribute is ignored
  * #8315: autodoc: Failed to resolve struct.Struct type annotation
  * #8652: autodoc: All variable comments in the module are ignored if the module
    contains invalid type comments
  * #8693: autodoc: Default values for overloaded functions are rendered as string
  * #8134: autodoc: crashes when mocked decorator takes arguments
  * #8800: autodoc: Uninitialized attributes in superclass are recognized as
    undocumented
  * #8655: autodoc: Failed to generate document if target module contains an
    object that raises an exception on ``hasattr()``
  * #8306: autosummary: mocked modules are documented as empty page when using
    :recursive: option
  * #8232: graphviz: Image node is not rendered if graph file is in subdirectory
  * #8618: html: kbd role produces incorrect HTML when compound-key separators (-,
    + or ^) are used as keystrokes
  * #8629: html: A type warning for html_use_opensearch is shown twice
  * #8714: html: kbd role with "Caps Lock" rendered incorrectly
  * #8123: html search: fix searching for terms containing + (Requires a custom
    search language that does not split on +)
  * #8665: html theme: Could not override globaltoc_maxdepth in theme.conf
  * #8446: html: consecutive spaces are displayed as single space
  * #8745: i18n: crashes with KeyError when translation message adds a new auto
    footnote reference
  * #4304: linkcheck: Fix race condition that could lead to checking the
    availability of the same URL twice
  * #8791: linkcheck: The docname for each hyperlink is not displayed
  * #7118: sphinx-quickstart: questionare got Mojibake if libreadline unavailable
  * #8094: texinfo: image files on the different directory with document are not
    copied
  * #8782: todo: Cross references in todolist get broken
  * #8720: viewcode: module pages are generated for epub on incremental build
  * #8704: viewcode: anchors are generated in incremental build after singlehtml
  * #8756: viewcode: highlighted code is generated even if not referenced
  * #8671: :confval:`highlight_options` is not working
  * #8341: C, fix intersphinx lookup types for names in declarations.
  * C, C++: in general fix intersphinx and role lookup types.
  * #8683: :confval:`html_last_updated_fmt` does not support UTC offset (%%z)
  * #8683: :confval:`html_last_updated_fmt` generates wrong time zone for %%Z
  * #1112: ``download`` role creates duplicated copies when relative path is
    specified
  * #2616 (fifth item): LaTeX: footnotes from captions are not clickable,
    and for manually numbered footnotes only first one with same number is
    an hyperlink
  * #7576: LaTeX with French babel and memoir crash: "Illegal parameter number
    in definition of ``\FNH@prefntext``"
  * #8055: LaTeX (docs): A potential display bug with the LaTeX generation step
    in Sphinx (how to generate one-column index)
  * #8072: LaTeX: Directive :rst:dir:`hlist` not implemented in LaTeX
  * #8214: LaTeX: The :rst:role:`index` role and the glossary generate duplicate
    entries in the LaTeX index (if both used for same term)
  * #8735: LaTeX: wrong internal links in pdf to captioned code-blocks when
    :confval:`numfig` is not True
  * #8442: LaTeX: some indexed terms are ignored when using xelatex engine
    (or pdflatex and :confval:`latex_use_xindy` set to True) with memoir class
  * #8750: LaTeX: URLs as footnotes fail to show in PDF if originating from
    inside function type signatures
  * #8780: LaTeX: long words in narrow columns may not be hyphenated
  * #8788: LaTeX: ``\titleformat`` last argument in sphinx.sty should be
    bracketed, not braced (and is anyhow not needed)
  * #8849: LaTex: code-block printed out of margin (see the opt-in LaTeX syntax
    boolean :ref:`verbatimforcewraps <latexsphinxsetupforcewraps>` for use via
    the :ref:`'sphinxsetup' <latexsphinxsetup>` key of ``latex_elements``)
  * #8183: LaTeX: Remove substitution_reference nodes from doctree only on LaTeX
    builds
  * #8865: LaTeX: Restructure the index nodes inside title nodes only on LaTeX
    builds
  * #8796: LaTeX: potentially critical low level TeX coding mistake has gone
    unnoticed so far
  * C, :rst:dir:`c:alias` skip symbols without explicit declarations
    instead of crashing.
  * C, :rst:dir:`c:alias` give a warning when the root symbol is not declared.
  * C, ``expr`` role should start symbol lookup in the current scope.
  * #8655: autodoc: Failed to generate document if target module contains an
    object that raises an exception on ``hasattr()``
* Wed Jan 13 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.4.3
  * Bugfix release, see upstream CHANGES
* Mon Jan 11 2021 Markéta Machová <mmachova@suse.com>
- Do not download python (and requests) documentation in the runtime.
- Add file requests.inv
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 3.4.1:
  * #8105: autodoc: the signature of class constructor will be shown for decorated
    classes, not a signature of decorator
  * #8119: autodoc: Allow to determine whether a member not included in
    ``__all__`` attribute of the module should be documented or not via
    :event:`autodoc-skip-member` event
  * #8219: autodoc: Parameters for generic class are not shown when super class is
    a generic class and show-inheritance option is given (in Python 3.7 or above)
  * autodoc: Add ``Documenter.config`` as a shortcut to access the config object
  * autodoc: Add Optional[t] to annotation of function and method if a default
    value equal to None is set.
  * #8209: autodoc: Add ``:no-value:`` option to :rst:dir:`autoattribute` and
    :rst:dir:`autodata` directive to suppress the default value of the variable
  * #8460: autodoc: Support custom types defined by typing.NewType
  * #8285: napoleon: Add :confval:`napoleon_attr_annotations` to merge type hints
    on source code automatically if any type is specified in docstring
  * #8236: napoleon: Support numpydoc's "Receives" section
  * #6914: Add a new event :event:`warn-missing-reference` to custom warning
    messages when failed to resolve a cross-reference
  * #6914: Emit a detailed warning when failed to resolve a ``:ref:`` reference
  * #6629: linkcheck: The builder now handles rate limits. See
    :confval:`linkcheck_retry_on_rate_limit` for details.
  * Large number of bugfixes, see included NEWS
- remove sphinx-pr8520-fix-AliasNode-copy.patch (upstream)
* Fri Dec  4 2020 Benjamin Greiner <code@bnavigator.de>
- Remove unused mypy from BuildRequires in :test
- Fix the intersphinx inventory bundle for multiple python flavors
  gh#openSUSE/python-rpm-macros#66
- Fix failing graphviz dot calls by including packages for png
  and pdf formats. The png fail was masked by an incorrect use of
  a shell command chain. Fails for pdf format were in the tests.
- Add sphinx-pr8520-fix-AliasNode-copy.patch to fix failing
  manpages build -- gh#sphinx-doc/sphinx#8520
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.3.1:
  * #8372: autodoc: autoclass directive became slower than Sphinx-3.2
  * #7727: autosummary: raise PycodeError when documenting python package
  * #8350: autosummary: autosummary_mock_imports causes slow down builds
  * #8364: C, properly initialize attributes in empty symbols.
  * #8399: i18n: Put system locale path after the paths specified by configuration
  * #8100: html: Show a better error message for failures on copying
  html_static_files
  * #8141: C: added a ``maxdepth`` option to :rst:dir:`c:alias` to insert
  nested declarations.
  * #8081: LaTeX: Allow to add LaTeX package via ``app.add_latex_package()`` until
  just before writing .tex file
  * #7996: manpage: Add :confval:`man_make_section_directory` to make a section
  directory on build man page
  * #8289: epub: Allow to suppress "duplicated ToC entry found" warnings from epub
  builder using :confval:`suppress_warnings`.
  * #8298: sphinx-quickstart: Add :option:`sphinx-quickstart --no-sep` option
  * #8304: sphinx.testing: Register public markers in sphinx.testing.fixtures
  * #8051: napoleon: use the obj role for all See Also items
  * #8050: napoleon: Apply :confval:`napoleon_preprocess_types` to every field
  * C and C++, show line numbers for previous declarations when duplicates are
  detected.
  * #8183: Remove substitution_reference nodes from doctree only on LaTeX builds
  * bugfixes
  - remove sphinx-pygments-compat.patch (obsolete)
* Wed Nov  4 2020 Benjamin Greiner <code@bnavigator.de>
- Fix the lang collection macro override.
  * gh#openSUSE/python-rpm-macros#66
  * gh#openSUSE/python-rpm-macros#74
* Tue Nov  3 2020 Benjamin Greiner <code@bnavigator.de>
- Fix lang files collection for multiple flavors
  * gh#openSUSE/python-rpm-macros#5
  * gh#openSUSE/python-rpm-macros#66
* Mon Sep 28 2020 Dirk Mueller <dmueller@suse.com>
- add sphinx-pygments-compat.patch (fix tests with newer pygments)
* Tue Aug 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.2.1:
  * #8095: napoleon: Add :confval:`napoleon_preprocess_types` to enable the type
    preprocessor for numpy style docstrings
  * #8114: C and C++, parse function attributes after parameters and qualifiers.
  * #8074: napoleon: Crashes during processing C-ext module
  * #8088: napoleon: "Inline literal start-string without end-string" warning in
    Numpy style Parameters section
  * #8084: autodoc: KeyError is raised on documenting an attribute of the broken
    class
  * #8091: autodoc: AttributeError is raised on documenting an attribute on Python
    3.5.2
  * #8099: autodoc: NameError is raised when target code uses ``TYPE_CHECKING``
  * C++, fix parsing of template template paramters, broken by the fix of #7944
* Thu Aug 13 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.2.0:
  * #2076: autodoc: Allow overriding of exclude-members in skip-member function
  * #8034: autodoc: ``:private-member:`` can take an explicit list of member names
    to be documented
  * #2024: autosummary: Add :confval:`autosummary_filename_map` to avoid conflict
    of filenames between two object with different case
  * #8011: autosummary: Support instance attributes as a target of autosummary
    directive
  * #7849: html: Add :confval:`html_codeblock_linenos_style` to change the style
    of line numbers for code-blocks
  * #7853: C and C++, support parameterized GNU style attributes.
  * #7888: napoleon: Add aliases Warn and Raise.
  * #7690: napoleon: parse type strings and make them hyperlinks as possible.  The
    conversion rule can be updated via :confval:`napoleon_type_aliases`
  * #8049: napoleon: Create a hyperlink for each the type of parameter when
    :confval:`napoleon_use_params` is False
  * C, added :rst:dir:`c:alias` directive for inserting copies
    of existing declarations.
  * #7745: html: inventory is broken if the docname contains a space
  * #7991: html search: Allow searching for numbers
  * #7902: html theme: Add a new option :confval:`globaltoc_maxdepth` to control
    the behavior of globaltoc in sidebar
  * #7840: i18n: Optimize the dependencies check on bootstrap
  * #7768: i18n: :confval:`figure_language_filename` supports ``docpath`` token
  * #5208: linkcheck: Support checks for local links
  * #5090: setuptools: Link verbosity to distutils' -v and -q option
  * #6698: doctest: Add ``:trim-doctest-flags:`` and ``:no-trim-doctest-flags:``
    options to doctest, testcode and testoutput directives
  * #7052: add ``:noindexentry:`` to the Python, C, C++, and Javascript domains.
    Update the documentation to better reflect the relationship between this option
    and the ``:noindex:`` option.
  * #7899: C, add possibility of parsing of some pre-v3 style type directives and
    roles and try to convert them to equivalent v3 directives/roles.
    Set the new option :confval:`c_allow_pre_v3` to ``True`` to enable this.
    The warnings printed from this functionality can be suppressed by setting
    :confval:`c_warn_on_allowed_pre_v3`` to ``True``.
    The functionality is immediately deprecated.
  * #7999: C, add support for named variadic macro arguments.
  * #8071: Allow to suppress "self referenced toctrees" warning
  * #7886: autodoc: TypeError is raised on mocking generic-typed classes
  * #7935: autodoc: function signature is not shown when the function has a
    parameter having ``inspect._empty`` as its default value
  * #7901: autodoc: type annotations for overloaded functions are not resolved
  * #904: autodoc: An instance attribute cause a crash of autofunction directive
  * #1362: autodoc: ``private-members`` option does not work for class attributes
  * #7983: autodoc: Generator type annotation is wrongly rendered in py36
  * #8030: autodoc: An uninitialized annotated instance variable is not documented
    when ``:inherited-members:`` option given
  * #8032: autodoc: A type hint for the instance variable defined at parent class
    is not shown in the document of the derived class
  * #8041: autodoc: An annotated instance variable on super class is not
    documented when derived class has other annotated instance variables
  * #7839: autosummary: cannot handle umlauts in function names
  * #7865: autosummary: Failed to extract summary line when abbreviations found
  * #7866: autosummary: Failed to extract correct summary line when docstring
    contains a hyperlink target
  * #7469: autosummary: "Module attributes" header is not translatable
  * #7940: apidoc: An extra newline is generated at the end of the rst file if a
    module has submodules
  * #4258: napoleon: decorated special methods are not shown
  * #7799: napoleon: parameters are not escaped for combined params in numpydoc
  * #7780: napoleon: multiple paramaters declaration in numpydoc was wrongly
    recognized when napoleon_use_params=True
  * #7715: LaTeX: ``numfig_secnum_depth > 1`` leads to wrong figure links
  * #7846: html theme: XML-invalid files were generated
  * #7894: gettext: Wrong source info is shown when using rst_epilog
  * #7691: linkcheck: HEAD requests are not used for checking
  * #4888: i18n: Failed to add an explicit title to ``:ref:`` role on translation
  * #7928: py domain: failed to resolve a type annotation for the attribute
  * #8008: py domain: failed to parse a type annotation containing ellipsis
  * #7994: std domain: option directive does not generate old node_id compatible
    with 2.x or older
  * #7968: i18n: The content of ``math`` directive is interpreted as reST on
    translation
  * #7768: i18n: The ``root`` element for :confval:`figure_language_filename` is
    not a path that user specifies in the document
  * #7993: texinfo: TypeError is raised for nested object descriptions
  * #7993: texinfo: a warning not supporting desc_signature_line node is shown
  * #7869: :rst:role:`abbr` role without an explanation will show the explanation
    from the previous abbr role
  * #8048: graphviz: graphviz.css was copied on building non-HTML document
  * C and C++, removed ``noindex`` directive option as it did
    nothing.
  * #7619: Duplicated node IDs are generated if node has multiple IDs
  * #2050: Symbols sections are appeared twice in the index page
  * #8017: Fix circular import in sphinx.addnodes
  * #7986: CSS: make "highlight" selector more robust
  * #7944: C++, parse non-type template parameters starting with
    a dependent qualified name.
  * C, don't deepcopy the entire symbol table and make a mess every time an
    enumerator is handled.
* Thu Jul 16 2020 Matej Cepl <mcepl@suse.com>
- In the new multiversion world, python*.inv is in python3.8
  directory not python3.
* Sat Jul 11 2020 Arun Persaud <arun@gmx.de>
- update to version 3.1.2:
  * Incompatible changes
    + #7650: autodoc: the signature of base function will be shown for
    decorated functions, not a signature of decorator
  * Bugs fixed
    + #7844: autodoc: Failed to detect module when relative module
    name given
    + #7856: autodoc: AttributeError is raised when non-class object
    is given to the autoclass directive
    + #7850: autodoc: KeyError is raised for invalid mark up when
    autodoc_typehints is 'description'
    + #7812: autodoc: crashed if the target name matches to both an
    attribute and module that are same name
    + #7650: autodoc: function signature becomes "(*args, **kwargs)"
    if the function is decorated by generic decorator
    + #7812: autosummary: generates broken stub files if the target
    code contains an attribute and module that are same name
    + #7806: viewcode: Failed to resolve viewcode references on 3rd
    party builders
    + #7838: html theme: List items have extra vertical space
    + #7878: html theme: Undesired interaction between "overflow" and
    "float"
- changes from version 3.1.1:
  * Incompatible changes
    + #7808: napoleon: a type for attribute are represented as typed
    field
  * Features added
    + #7807: autodoc: Show detailed warning when type_comment is
    mismatched with its signature
  * Bugs fixed
    + #7808: autodoc: Warnings raised on variable and attribute type
    annotations
    + #7802: autodoc: EOFError is raised on parallel build
    + #7821: autodoc: TypeError is raised for overloaded C-ext
    function
    + #7805: autodoc: an object which descriptors returns is
    unexpectedly documented
    + #7807: autodoc: wrong signature is shown for the function using
    contextmanager
    + #7812: autosummary: generates broken stub files if the target
    code contains an attribute and module that are same name
    + #7808: napoleon: Warnings raised on variable and attribute type
    annotations
    + #7811: sphinx.util.inspect causes circular import problem
- changes from version 3.1.0:
  * Dependencies
    + #7746: mathjax: Update to 2.7.5
  * Incompatible changes
    + #7477: imgconverter: Invoke "magick convert" command by default
    on Windows
  * Deprecated
    + The first argument for
    sphinx.ext.autosummary.generate.AutosummaryRenderer has been
    changed to Sphinx object
    + "sphinx.ext.autosummary.generate.AutosummaryRenderer" takes an
    object type as an argument
    + The "ignore" argument of
    "sphinx.ext.autodoc.Documenter.get_doc()"
    + The "template_dir" argument of "sphinx.ext.autosummary.generate.
    AutosummaryRenderer"
    + The "module" argument of "sphinx.ext.autosummary.generate.
    find_autosummary_in_docstring()"
    + The "builder" argument of "sphinx.ext.autosummary.generate.
    generate_autosummary_docs()"
    + The "template_dir" argument of "sphinx.ext.autosummary.generate.
    generate_autosummary_docs()"
    + The "ignore" argument of
    "sphinx.util.docstring.prepare_docstring()"
    + "sphinx.ext.autosummary.generate.AutosummaryRenderer.exists()"
    + "sphinx.util.rpartition()"
  * Features added
    + LaTeX: Make the "toplevel_sectioning" setting optional in LaTeX
    theme
    + LaTeX: Allow to override papersize and pointsize from LaTeX
    themes
    + LaTeX: Add :confval:`latex_theme_options` to override theme
    options
    + #7410: Allow to suppress "circular toctree references detected"
    warnings using :confval:`suppress_warnings`
    + C, added scope control directives, :rst:dir:`c:namespace`,
    :rst:dir:`c:namespace-push`, and :rst:dir:`c:namespace-pop`.
    + #2044: autodoc: Suppress default value for instance attributes
    + #7473: autodoc: consider a member public if docstring contains
    ":meta public:" in info-field-list
    + #7487: autodoc: Allow to generate docs for singledispatch
    functions by py:autofunction
    + #7143: autodoc: Support final classes and methods
    + #7384: autodoc: Support signatures defined by "__new__()",
    metaclasses and builtin base classes
    + #2106: autodoc: Support multiple signatures on docstring
    + #4422: autodoc: Support GenericAlias in Python 3.7 or above
    + #3610: autodoc: Support overloaded functions
    + #7722: autodoc: Support TypeVar
    + #7466: autosummary: headings in generated documents are not
    translated
    + #7490: autosummary: Add ":caption:" option to autosummary
    directive to set a caption to the toctree
    + #7469: autosummary: Support module attributes
    + #248, #6040: autosummary: Add ":recursive:" option to
    autosummary directive to generate stub files recursively
    + #4030: autosummary: Add :confval:`autosummary_context` to add
    template variables for custom templates
    + #7530: html: Support nested <kbd> elements
    + #7481: html theme: Add right margin to footnote/citation labels
    + #7482, #7717: html theme: CSS spacing for code blocks with
    captions and line numbers
    + #7443: html theme: Add new options :confval:`globaltoc_collapse`
    and :confval:`globaltoc_includehidden` to control the behavior
    of globaltoc in sidebar
    + #7484: html theme: Avoid clashes between sidebar and other
    blocks
    + #7476: html theme: Relbar breadcrumb should contain current page
    + #7506: html theme: A canonical URL is not escaped
    + #7533: html theme: Avoid whitespace at the beginning of
    genindex.html
    + #7541: html theme: Add a "clearer" at the end of the "body"
    + #7542: html theme: Make admonition/topic/sidebar scrollable
    + #7543: html theme: Add top and bottom margins to tables
    + #7695: html theme: Add viewport meta tag for basic theme
    + #7721: html theme: classic: default codetextcolor/codebgcolor
    doesn't override Pygments
    + C and C++: allow semicolon in the end of declarations.
    + C++, parse parameterized noexcept specifiers.
    + #7294: C++, parse expressions with user-defined literals.
    + C++, parse trailing return types.
    + #7143: py domain: Add ":final:" option to :rst:dir:`py:class:`,
    :rst:dir:`py:exception:` and :rst:dir:`py:method:` directives
    + #7596: py domain: Change a type annotation for variables to a
    hyperlink
    + #7770: std domain: :rst:dir:`option` directive support arguments
    in the form of "foo[=bar]"
    + #7582: napoleon: a type for attribute are represented like type
    annotation
    + #7734: napoleon: overescaped trailing underscore on attribute
    + #7247: linkcheck: Add :confval:`linkcheck_request_headers` to
    send custom HTTP headers for specific host
    + #7792: setuptools: Support "--verbosity" option
    + #7683: Add "allowed_exceptions" parameter to "Sphinx.emit()" to
    allow handlers to raise specified exceptions
    + #7295: C++, parse (trailing) requires clauses.
  * Bugs fixed
    + #6703: autodoc: incremental build does not work for imported
    objects
    + #7564: autodoc: annotations not to be shown for descriptors
    + #6588: autodoc: Decorated inherited method has no documentation
    + #7469: autodoc: The change of autodoc-process-docstring for
    variables is cached unexpectedly
    + #7559: autodoc: misdetects a sync function is async
    + #6857: autodoc: failed to detect a classmethod on Enum class
    + #7562: autodoc: a typehint contains spaces is wrongly rendered
    under autodoc_typehints='description' mode
    + #7551: autodoc: failed to import nested class
    + #7362: autodoc: does not render correct signatures for built-in
    functions
    + #7654: autodoc: "Optional[Union[foo, bar]]" is presented as
    "Union[foo, bar, None]"
    + #7629: autodoc: autofunction emits an unfriendly warning if an
    invalid object specified
    + #7650: autodoc: undecorated signature is shown for decorated
    functions
    + #7676: autodoc: typo in the default value of
    autodoc_member_order
    + #7676: autodoc: wrong value for :member-order: option is ignored
    silently
    + #7676: autodoc: member-order="bysource" does not work for C
    module
    + #3673: autodoc: member-order="bysource" does not work for a
    module having __all__
    + #7668: autodoc: wrong retann value is passed to a handler of
    autodoc-proccess-signature
    + #7711: autodoc: fails with ValueError when processing numpy
    objects
    + #7791: autodoc: TypeError is raised on documenting
    singledispatch function
    + #7551: autosummary: a nested class is indexed as non-nested
    class
    + #7661: autosummary: autosummary directive emits warnings twices
    if failed to import the target module
    + #7685: autosummary: The template variable "members" contains
    imported members even if
    :confval:`autossummary_imported_members` is False
    + #7671: autosummary: The location of import failure warning is
    missing
    + #7535: sphinx-autogen: crashes when custom template uses
    inheritance
    + #7536: sphinx-autogen: crashes when template uses i18n feature
    + #7781: sphinx-build: Wrong error message when outdir is not
    directory
    + #7653: sphinx-quickstart: Fix multiple directory creation for
    nested relpath
    + #2785: html: Bad alignment of equation links
    + #7718: html theme: some themes does not respect background color
    of Pygments style (agogo, haiku, nature, pyramid, scrolls,
    sphinxdoc and traditional)
    + #7544: html theme: inconsistent padding in admonitions
    + #7581: napoleon: bad parsing of inline code in attribute
    docstrings
    + #7628: imgconverter: runs imagemagick once unnecessary for
    builders not supporting images
    + #7610: incorrectly renders consecutive backslashes for
    docutils-0.16
    + #7646: handle errors on event handlers
    + #4187: LaTeX: EN DASH disappears from PDF bookmarks in Japanese
    documents
    + #7701: LaTeX: Anonymous indirect hyperlink target causes
    duplicated labels
    + #7723: LaTeX: pdflatex crashed when URL contains a single quote
    + #7756: py domain: The default value for positional only argument
    is not shown
    + #7760: coverage: Add :confval:`coverage_show_missing_items` to
    show coverage result to console
    + C++, fix rendering and xrefs in nested names explicitly starting
    in global scope, e.g., "::A::B".
    + C, fix rendering and xrefs in nested names explicitly starting
    in global scope, e.g., ".A.B".
    + #7763: C and C++, don't crash during display stringification of
    unary expressions and fold expressions.
* Sat May 30 2020 Arun Persaud <arun@gmx.de>
- update to version 3.0.4:
  * Bugs fixed
    + #7567: autodoc: parametrized types are shown twice for generic
    types
    + #7637: autodoc: system defined TypeVars are shown in Python 3.9
    + #7611: md5 fails when OpenSSL FIPS is enabled
    + #7626: release package does not contain "CODE_OF_CONDUCT"
* Mon May  4 2020 Jan Zerebecki <jzerebecki@suse.com>
- Add python3.inv as a specific Source.
- update to version 3.0.3
  * Features added
  * C, parse array declarators with static, qualifiers, and VLA specification.
  * Bugs fixed
  * #7516: autodoc: crashes if target object raises an error on accessing
    its attributes
- update to version 3.0.2
  * Features added
  * C, parse attributes and add :confval:`c_id_attributes`
    and :confval:`c_paren_attributes` to support user-defined attributes.
  * Bugs fixed
  * #7461: py domain: fails with IndexError for empty tuple in type annotation
  * #7510: py domain: keyword-only arguments are documented as having a default of
    None
  * #7418: std domain: :rst:role:`term` role could not match case-insensitively
  * #7461: autodoc: empty tuple in type annotation is not shown correctly
  * #7479: autodoc: Sphinx builds has been slower since 3.0.0 on mocking
  * C++, fix spacing issue in east-const declarations.
  * #7414: LaTeX: Xindy language options were incorrect
  * sphinx crashes with ImportError on python3.5.1
- update to 3.0.1
  * Incompatible changes
  * #7418: std domain: :rst:dir:`term` role becomes case sensitive
  * Bugs fixed
  * #7428: py domain: a reference to class ``None`` emits a nitpicky warning
  * #7445: py domain: a return annotation ``None`` in the function signature is
    not converted to a hyperlink when using intersphinx
  * #7418: std domain: duplication warning for glossary terms is case insensitive
  * #7438: C++, fix merging overloaded functions in parallel builds.
  * #7422: autodoc: fails with ValueError when using autodoc_mock_imports
  * #7435: autodoc: ``autodoc_typehints='description'`` doesn't suppress typehints
    in signature for classes/methods
  * #7451: autodoc: fails with AttributeError when an object returns non-string
    object as a ``__doc__`` member
  * #7423: crashed when giving a non-string object to logger
  * #7479: html theme: Do not include xmlns attribute with HTML 5 doctype
  * #7426: html theme: Escape some links in HTML templates
- update to version 3.0.0
  * Dependencies
  * LaTeX: drop dependency on :program:`extractbb` for image inclusion in
    Japanese documents as ``.xbb`` files are unneeded by :program:`dvipdfmx`
    since TeXLive2015 (refs: #6189)
  * babel-2.0 or above is available (Unpinned)
  * Incompatible changes
  * Drop features and APIs deprecated in 1.8.x
  * #247: autosummary: stub files are overwritten automatically by default.  see
    :confval:`autosummary_generate_overwrite` to change the behavior
  * #5923: autodoc: the members of ``object`` class are not documented by default
    when ``:inherited-members:`` and ``:special-members:`` are given.
  * #6830: py domain: ``meta`` fields in info-field-list becomes reserved.  They
    are not displayed on output document now
  * #6417: py domain: doctree of desc_parameterlist has been changed.  The
    argument names, annotations and default values are wrapped with inline node
  * The structure of ``sphinx.events.EventManager.listeners`` has changed
  * Due to the scoping changes for :rst:dir:`productionlist` some uses of
    :rst:role:`token` must be modified to include the scope which was previously
    ignored.
  * #6903: Internal data structure of Python, reST and standard domains have
    changed.  The node_id is added to the index of objects and modules.  Now they
    contains a pair of docname and node_id for cross reference.
  * #7276: C++ domain: Non intended behavior is removed such as ``say_hello_``
    links to ``.. cpp:function:: say_hello()``
  * #7210: js domain: Non intended behavior is removed such as ``parseInt_`` links
    to ``.. js:function:: parseInt``
  * #7229: rst domain: Non intended behavior is removed such as ``numref_`` links
    to ``.. rst:role:: numref``
  * #6903: py domain: Non intended behavior is removed such as ``say_hello_``
    links to ``.. py:function:: say_hello()``
  * #7246: py domain: Drop special cross reference helper for exceptions,
    functions and methods
  * The C domain has been rewritten, with additional directives and roles.
    The existing ones are now more strict, resulting in new warnings.
  * The attribute ``sphinx_cpp_tagname`` in the ``desc_signature_line`` node
    has been renamed to ``sphinx_line_type``.
  * #6462: double backslashes in domain directives are no longer replaced by
    single backslashes as default. A new configuration value
    :confval:`strip_signature_backslash` can be used by users to reenable it.
  * #7222: ``sphinx.util.inspect.unwrap()`` is renamed to ``unwrap_all()``
  * Deprecated
  * ``desc_signature['first']``
  * ``sphinx.directives.DescDirective``
  * ``sphinx.domains.std.StandardDomain.add_object()``
  * ``sphinx.domains.python.PyDecoratorMixin``
  * ``sphinx.ext.autodoc.get_documenters()``
  * ``sphinx.ext.autosummary.process_autosummary_toc()``
  * ``sphinx.parsers.Parser.app``
  * ``sphinx.testing.path.Path.text()``
  * ``sphinx.testing.path.Path.bytes()``
  * ``sphinx.util.inspect.getargspec()``
  * ``sphinx.writers.latex.LaTeXWriter.format_docclass()``
  * Features added
  * #247: autosummary: Add :confval:`autosummary_generate_overwrite` to overwrite
    old stub file
  * #5923: autodoc: ``:inherited-members:`` option takes a name of anchestor class
    not to document inherited members of the class and uppers
  * #6830: autodoc: consider a member private if docstring contains
    ``:meta private:`` in info-field-list
  * #7165: autodoc: Support Annotated type (PEP-593)
  * #2815: autodoc: Support singledispatch functions and methods
  * #7079: autodoc: :confval:`autodoc_typehints` accepts ``"description"``
    configuration.  It shows typehints as object description
  * #7314: apidoc: Propagate ``--maxdepth`` option through package documents
  * #6558: glossary: emit a warning for duplicated glossary entry
  * #3106: domain: Register hyperlink target for index page automatically
  * #6558: std domain: emit a warning for duplicated generic objects
  * #6830: py domain: Add new event: :event:`object-description-transform`
  * #6895: py domain: Do not emit nitpicky warnings for built-in types
  * py domain: Support lambda functions in function signature
  * #6417: py domain: Allow to make a style for arguments of functions and methods
  * #7238, #7239: py domain: Emit a warning on describing a python object if the
    entry is already added as the same name
  * #7341: py domain: type annotations in singature are converted to cross refs
  * Support priority of event handlers. For more detail, see
    :py:meth:`.Sphinx.connect()`
  * #3077: Implement the scoping for :rst:dir:`productionlist` as indicated
    in the documentation.
  * #1027: Support backslash line continuation in :rst:dir:`productionlist`.
  * #7108: config: Allow to show an error message from conf.py via ``ConfigError``
  * #7032: html: :confval:`html_scaled_image_link` will be disabled for images having
    ``no-scaled-link`` class
  * #7144: Add CSS class indicating its domain for each desc node
  * #7211: latex: Use babel for Chinese document when using XeLaTeX
  * #6672: LaTeX: Support LaTeX Theming (experimental)
  * #7005: LaTeX: Add LaTeX styling macro for :rst:role:`kbd` role
  * #7220: genindex: Show "main" index entries at first
  * #7103: linkcheck: writes all links to ``output.json``
  * #7025: html search: full text search can be disabled for individual document
    using ``:nosearch:`` file-wide metadata
  * #7293: html search: Allow to override JavaScript splitter via
    ``SearchLanguage.js_splitter_code``
  * #7142: html theme: Add a theme option: ``pygments_dark_style`` to switch the
    style of code-blocks in dark mode
  * The C domain has been rewritten adding for example:
  - Cross-referencing respecting the current scope.
  - Possible to document anonymous entities.
  - More specific directives and roles for each type of entitiy,
    e.g., handling scoping of enumerators.
  - New role :rst:role:`c:expr` for rendering expressions and types
    in text.
  * Added ``SphinxDirective.get_source_info()``
    and ``SphinxRole.get_source_info()``.
  * #7324: sphinx-build: Emit a warning if multiple files having different file
    extensions for same document found
  * Added ``ObjectDescription.transform_content()``.
  * Bugs fixed
  * C++, fix cross reference lookup in certain cases involving
    function overloads.
  * #5078: C++, fix cross reference lookup when a directive contains multiple
    declarations.
  * C++, suppress warnings for directly dependent typenames in cross references
    generated automatically in signatures.
  * #5637: autodoc: Incorrect handling of nested class names on show-inheritance
  * #7267: autodoc: error message for invalid directive options has wrong location
  * #7329: autodoc: info-field-list is wrongly generated from type hints into the
    class description even if ``autoclass_content='class'`` set
  * #7331: autodoc: a cython-function is not recognized as a function
  * #5637: inheritance_diagram: Incorrect handling of nested class names
  * #7139: ``code-block:: guess`` does not work
  * #7325: html: source_suffix containing dot leads to wrong source link
  * #7357: html: Resizing SVG image fails with ValueError
  * #7278: html search: Fix use of ``html_file_suffix`` instead of
    ``html_link_suffix`` in search results
  * #7297: html theme: ``bizstyle`` does not support ``sidebarwidth``
  * #3842: singlehtml: Path to images broken when master doc is not in source root
  * #7179: std domain: Fix whitespaces are suppressed on referring GenericObject
  * #7289: console: use bright colors instead of bold
  * #1539: C, parse array types.
  * #2377: C, parse function pointers even in complex types.
  * #7345: sphinx-build: Sphinx crashes if output directory exists as a file
  * #7290: sphinx-build: Ignore bdb.BdbQuit when handling exceptions
  * #6240: napoleon: Attributes and Methods sections ignore :noindex: option
  * #7364: autosummary: crashed when :confval:`autosummary_generate` is False
  * #7370: autosummary: raises UnboundLocalError when unknown module given
  * #7367: C++, alternate operator spellings are now supported.
  * C, alternate operator spellings are now supported.
  * #7368: C++, comma operator in expressions, pack expansion in template
    argument lists, and more comprehensive error messages in some cases.
  * C, C++, fix crash and wrong duplicate warnings related to anon symbols.
  * #6477: Escape first "!" in a cross reference linking no longer possible
  * #7219: py domain: The index entry generated by ``py:function`` directive is
    different with one from ``index`` directive with "builtin" type
  * #7301: capital characters are not allowed for node_id
  * #7301: epub: duplicated node_ids are generated
  * #6564: html: a width of table was ignored on HTML builder
  * #7401: Incorrect argument is passed for :event:`env-get-outdated` handlers
  * #7355: autodoc: a signature of cython-function is not recognized well
  * #7222: autodoc: ``__wrapped__`` functions are not documented correctly
  * #7409: intersphinx: ValueError is raised when an extension sets up
    :confval:`intersphinx_mapping` on :event:`config-inited` event
  * #7343: Sphinx builds has been slower since 2.4.0 on debug mode
- update to version 2.4.4
  * Bugs fixed
  * #7197: LaTeX: platex cause error to build image directive with target url
  * #7223: Sphinx builds has been slower since 2.4.0
- update to version 2.4.3
  * Bugs fixed
  * #7184: autodoc: ``*args`` and ``**kwarg`` in type comments are not handled
    properly
  * #7189: autodoc: classmethod coroutines are not detected
  * #7183: intersphinx: ``:attr:`` reference to property is broken
  * #6244, #6387: html search: Search breaks/hangs when built with dirhtml builder
  * #7195: todo: emit doctree-resolved event with non-document node incorrectly
- update to version 2.4.2
  * Bugs fixed
  * #7138: autodoc: ``autodoc.typehints`` crashed when variable has unbound object
    as a value
  * #7156: autodoc: separator for keyword only arguments is not shown
  * #7146: autodoc: IndexError is raised on suppressed type_comment found
  * #7161: autodoc: typehints extension does not support parallel build
  * #7178: autodoc: TypeError is raised on fetching type annotations
  * #7151: crashed when extension assigns a value to ``env.indexentries``
  * #7170: text: Remove debug print
  * #7137: viewcode: Avoid to crash when non-python code given
- update to version 2.4.1
  * Bugs fixed
  * #7120: html: crashed when on scaling SVG images which have float dimentions
  * #7126: autodoc: TypeError: 'getset_descriptor' object is not iterable
- update to version 2.4.0
  * Deprecated
  * The ``decode`` argument of ``sphinx.pycode.ModuleAnalyzer()``
  * ``sphinx.directives.other.Index``
  * ``sphinx.environment.temp_data['gloss_entries']``
  * ``sphinx.environment.BuildEnvironment.indexentries``
  * ``sphinx.environment.collectors.indexentries.IndexEntriesCollector``
  * ``sphinx.ext.apidoc.INITPY``
  * ``sphinx.ext.apidoc.shall_skip()``
  * ``sphinx.io.FiletypeNotFoundError``
  * ``sphinx.io.get_filetype()``
  * ``sphinx.pycode.ModuleAnalyzer.encoding``
  * ``sphinx.roles.Index``
  * ``sphinx.util.detect_encoding()``
  * ``sphinx.util.get_module_source()``
  * ``sphinx.util.inspect.Signature``
  * ``sphinx.util.inspect.safe_getmembers()``
  * ``sphinx.writers.latex.LaTeXTranslator.settings.author``
  * ``sphinx.writers.latex.LaTeXTranslator.settings.contentsname``
  * ``sphinx.writers.latex.LaTeXTranslator.settings.docclass``
  * ``sphinx.writers.latex.LaTeXTranslator.settings.docname``
  * ``sphinx.writers.latex.LaTeXTranslator.settings.title``
  * ``sphinx.writers.latex.ADDITIONAL_SETTINGS``
  * ``sphinx.writers.latex.DEFAULT_SETTINGS``
  * ``sphinx.writers.latex.LUALATEX_DEFAULT_FONTPKG``
  * ``sphinx.writers.latex.PDFLATEX_DEFAULT_FONTPKG``
  * ``sphinx.writers.latex.XELATEX_DEFAULT_FONTPKG``
  * ``sphinx.writers.latex.XELATEX_GREEK_DEFAULT_FONTPKG``
  * Features added
  * #6910: inheritance_diagram: Make the background of diagrams transparent
  * #6446: duration: Add ``sphinx.ext.durations`` to inspect which documents slow
    down the build
  * #6837: LaTeX: Support a nested table
  * #7115: LaTeX: Allow to override LATEXOPTS and LATEXMKOPTS via environment
    variable
  * #6966: graphviz: Support ``:class:`` option
  * #6696: html: ``:scale:`` option of image/figure directive not working for SVG
    images (imagesize-1.2.0 or above is required)
  * #6994: imgconverter: Support illustrator file (.ai) to .png conversion
  * autodoc: Support Positional-Only Argument separator (PEP-570 compliant)
  * autodoc: Support type annotations for variables
  * #2755: autodoc: Add new event: :event:`autodoc-before-process-signature`
  * #2755: autodoc: Support type_comment style (ex. ``# type: (str) -> str``)
    annotation (python3.8+ or `typed_ast <https://github.com/python/typed_ast>`_
    is required)
  * #7051: autodoc: Support instance variables without defaults (PEP-526)
  * #6418: autodoc: Add a new extension ``sphinx.ext.autodoc.typehints``. It shows
    typehints as object description if ``autodoc_typehints = "description"`` set.
    This is an experimental extension and it will be integrated into autodoc core
    in Sphinx-3.0
  * SphinxTranslator now calls visitor/departure method for super node class if
    visitor/departure method for original node class not found
  * #6418: Add new event: :event:`object-description-transform`
  * py domain: :rst:dir:`py:data` and :rst:dir:`py:attribute` take new options
    named ``:type:`` and ``:value:`` to describe its type and initial value
  * #6785: py domain: ``:py:attr:`` is able to refer properties again
  * #6772: apidoc: Add ``-q`` option for quiet mode
  * Bugs fixed
  * #6925: html: Remove redundant type="text/javascript" from <script> elements
  * #7112: html: SVG image is not layouted as float even if aligned
  * #6906, #6907: autodoc: failed to read the source codes encoeded in cp1251
  * #6961: latex: warning for babel shown twice
  * #7059: latex: LaTeX compilation falls into infinite loop (wrapfig issue)
  * #6581: latex: ``:reversed:`` option for toctree does not effect to LaTeX build
  * #6559: Wrong node-ids are generated in glossary directive
  * #6986: apidoc: misdetects module name for .so file inside module
  * #6899: apidoc: private members are not shown even if ``--private`` given
  * #6327: apidoc: Support a python package consisted of __init__.so file
  * #6999: napoleon: fails to parse tilde in :exc: role
  * #7019: gettext: Absolute path used in message catalogs
  * #7023: autodoc: nested partial functions are not listed
  * #7023: autodoc: partial functions imported from other modules are listed as
    module members without :impoprted-members: option
  * #6889: autodoc: Trailing comma in ``:members::`` option causes cryptic warning
  * #6568: autosummary: ``autosummary_imported_members`` is ignored on generating
    a stub file for submodule
  * #7055: linkcheck: redirect is treated as an error
  * #7088: HTML template: If ``navigation_with_keys`` option is activated,
    modifier keys are ignored, which means the feature can interfere with browser
    features
  * #7090: std domain: Can't assign numfig-numbers for custom container nodes
  * #7106: std domain: enumerated nodes are marked as duplicated when extensions
    call ``note_explicit_target()``
  * #7095: dirhtml: Cross references are broken via intersphinx and ``:doc:`` role
  * C++:
  - Don't crash when using the ``struct`` role in some cases.
  - Don't warn when using the ``var``/``member`` role for function
    parameters.
  - Render call and braced-init expressions correctly.
  * #7097: Filenames of images generated by
    ``sphinx.transforms.post_transforms.images.ImageConverter``
    or its subclasses (used for latex build) are now sanitized,
    to prevent broken paths
* Tue Apr  7 2020 Steve Kowalik <steven.kowalik@suse.com>
- Revert to 2.3.1 due to severely increased memory usage when building
  kernel documentation. bsc#1166965
* Sun Mar  8 2020 Arun Persaud <arun@gmx.de>
- update to version 2.4.4:
  * #7197: LaTeX: platex cause error to build image directive with
    target url
  * #7223: Sphinx builds has been slower since 2.4.0
* Sat Feb 22 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 2.4.3:
  * Bugs fixed
    + #7184: autodoc: "*args" and "**kwarg" in type comments are not
    handled properly
    + #7189: autodoc: classmethod coroutines are not detected
    + #7183: intersphinx: ":attr:" reference to property is broken
    + #6244, #6387: html search: Search breaks/hangs when built with
    dirhtml builder
    + #7195: todo: emit doctree-resolved event with non-document node
    incorrectly
- changes from version 2.4.2:
  * Bugs fixed
    + #7138: autodoc: "autodoc.typehints" crashed when variable has
    unbound object as a value
    + #7156: autodoc: separator for keyword only arguments is not
    shown
    + #7146: autodoc: IndexError is raised on suppressed type_comment
    found
    + #7161: autodoc: typehints extension does not support parallel
    build
    + #7178: autodoc: TypeError is raised on fetching type annotations
    + #7151: crashed when extension assigns a value to
    "env.indexentries"
    + #7170: text: Remove debug print
    + #7137: viewcode: Avoid to crash when non-python code given
- changes from version 2.4.1:
  * Bugs fixed
    + #7120: html: crashed when on scaling SVG images which have float
    dimentions
    + #7126: autodoc: TypeError: 'getset_descriptor' object is not
    iterable
- changes from version 2.4.0:
  * Deprecated
    + The "decode" argument of "sphinx.pycode.ModuleAnalyzer()"
    + "sphinx.directives.other.Index"
    + "sphinx.environment.temp_data['gloss_entries']"
    + "sphinx.environment.BuildEnvironment.indexentries"
    +
    "sphinx.environment.collectors.indexentries.IndexEntriesCollector"
    + "sphinx.ext.apidoc.INITPY"
    + "sphinx.ext.apidoc.shall_skip()"
    + "sphinx.io.FiletypeNotFoundError"
    + "sphinx.io.get_filetype()"
    + "sphinx.pycode.ModuleAnalyzer.encoding"
    + "sphinx.roles.Index"
    + "sphinx.util.detect_encoding()"
    + "sphinx.util.get_module_source()"
    + "sphinx.util.inspect.Signature"
    + "sphinx.util.inspect.safe_getmembers()"
    + "sphinx.writers.latex.LaTeXTranslator.settings.author"
    + "sphinx.writers.latex.LaTeXTranslator.settings.contentsname"
    + "sphinx.writers.latex.LaTeXTranslator.settings.docclass"
    + "sphinx.writers.latex.LaTeXTranslator.settings.docname"
    + "sphinx.writers.latex.LaTeXTranslator.settings.title"
    + "sphinx.writers.latex.ADDITIONAL_SETTINGS"
    + "sphinx.writers.latex.DEFAULT_SETTINGS"
    + "sphinx.writers.latex.LUALATEX_DEFAULT_FONTPKG"
    + "sphinx.writers.latex.PDFLATEX_DEFAULT_FONTPKG"
    + "sphinx.writers.latex.XELATEX_DEFAULT_FONTPKG"
    + "sphinx.writers.latex.XELATEX_GREEK_DEFAULT_FONTPKG"
  * Features added
    + #6910: inheritance_diagram: Make the background of diagrams
    transparent
    + #6446: duration: Add "sphinx.ext.durations" to inspect which
    documents slow down the build
    + #6837: LaTeX: Support a nested table
    + #7115: LaTeX: Allow to override LATEXOPTS and LATEXMKOPTS via
    environment variable
    + #6966: graphviz: Support ":class:" option
    + #6696: html: ":scale:" option of image/figure directive not
    working for SVG images (imagesize-1.2.0 or above is required)
    + #7025: html search: full text search can be disabled for
    individual document using ":nosearch:" file-wide metadata
    + #6994: imgconverter: Support illustrator file (.ai) to .png
    conversion
    + autodoc: Support Positional-Only Argument separator (PEP-570
    compliant)
    + autodoc: Support type annotations for variables
    + #2755: autodoc: Add new event:
    :event:`autodoc-before-process-signature`
    + #2755: autodoc: Support type_comment style (ex. "# type: (str)
  - > str") annotation (python3.8+ or `typed_ast
    <https://github.com/python/typed_ast>`_ is required)
    + #7051: autodoc: Support instance variables without defaults
    (PEP-526)
    + #6418: autodoc: Add a new extension
    "sphinx.ext.autodoc.typehints". It shows typehints as object
    description if "autodoc_typehints = "description"" set.  This
    is an experimental extension and it will be integrated into
    autodoc core in Sphinx-3.0
    + SphinxTranslator now calls visitor/departure method for super
    node class if visitor/departure method for original node class
    not found
    + #6418: Add new event: :event:`object-description-transform`
    + py domain: :rst:dir:`py:data` and :rst:dir:`py:attribute` take
    new options named ":type:" and ":value:" to describe its type
    and initial value
    + #6785: py domain: ":py:attr:" is able to refer properties again
    + #6772: apidoc: Add "-q" option for quiet mode
  * Bugs fixed
    + #6925: html: Remove redundant type="text/javascript" from
    <script> elements
    + #7112: html: SVG image is not layouted as float even if aligned
    + #6906, #6907: autodoc: failed to read the source codes encoeded
    in cp1251
    + #6961: latex: warning for babel shown twice
    + #7059: latex: LaTeX compilation falls into infinite loop
    (wrapfig issue)
    + #6581: latex: ":reversed:" option for toctree does not effect to
    LaTeX build
    + #6559: Wrong node-ids are generated in glossary directive
    + #6986: apidoc: misdetects module name for .so file inside module
    + #6899: apidoc: private members are not shown even if "--private"
    given
    + #6327: apidoc: Support a python package consisted of __init__.so
    file
    + #6999: napoleon: fails to parse tilde in :exc: role
    + #7019: gettext: Absolute path used in message catalogs
    + #7023: autodoc: nested partial functions are not listed
    + #7023: autodoc: partial functions imported from other modules
    are listed as module members without :impoprted-members: option
    + #6889: autodoc: Trailing comma in ":members::" option causes
    cryptic warning
    + #6568: autosummary: "autosummary_imported_members" is ignored on
    generating a stub file for submodule
    + #7055: linkcheck: redirect is treated as an error
    + #7088: HTML template: If "navigation_with_keys" option is
    activated, modifier keys are ignored, which means the feature
    can interfere with browser features
    + #7090: std domain: Can't assign numfig-numbers for custom
    container nodes
    + #7106: std domain: enumerated nodes are marked as duplicated
    when extensions call "note_explicit_target()"
    + #7095: dirhtml: Cross references are broken via intersphinx and
    ":doc:" role
    + C++:
  - Don't crash when using the ``struct`` role in some cases.
  - Don't warn when using the ``var``/``member`` role for function parameters.
  - Render call and braced-init expressions correctly.
    + #7097: Filenames of images generated by
    "sphinx.transforms.post_transforms.images.ImageConverter" or
    its subclasses (used for latex build) are now sanitized, to
    prevent broken paths
* Wed Dec 25 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.3.1
  * #6936: sphinx-autogen: raises AttributeError
  version 2.3.0:
  * #6742: ``end-before`` option of :rst:dir:`literalinclude`
    directive does not match the first line of the code block.
  * #1331: Change default User-Agent header to ``"Sphinx/X.Y.Z
    requests/X.Y.Z python/X.Y.Z"``.  It can be changed via
    :confval:`user_agent`.
  * #6867: text: content of admonitions starts after a blank line
  * #6707: C++, support bit-fields.
  * #267: html: Eliminate prompt characters of doctest block
    from copyable text
  * #6548: html: Use favicon for OpenSearch if available
  * #6729: html theme: agogo theme now supports ``rightsidebar``
    option
  * #6780: Add PEP-561 Support
  * #6762: latex: Allow to load additonal LaTeX packages via
    ``extrapackages`` key of :confval:`latex_elements`
  * #1331: Add new config variable: :confval:`user_agent`
  * #6000: LaTeX: have backslash also be an inline literal word
    wrap break character
  * #4186: LaTeX: Support upLaTeX as a new
    :confval:`latex_engine` (experimental)
  * #6812: Improve a warning message when extensions are not
    parallel safe
  * #6818: Improve Intersphinx performance for multiple remote
    inventories.
  * #2546: apidoc: .so file support
  * #6798: autosummary: emit ``autodoc-skip-member`` event on
    generating stub file
  * #6483: i18n: make explicit titles in toctree translatable
  * #6816: linkcheck: Add :confval:`linkcheck_auth` option to
    provide authentication information when doing ``linkcheck``
    builds
  * #6872: linkcheck: Handles HTTP 308 Permanent Redirect
  * #6613: html: Wrap section number in span tag
  * #6781: gettext: Add :confval:`gettext_last_translator' and
    :confval:`gettext_language_team` to customize headers of POT
    file
* Sat Dec  7 2019 Arun Persaud <arun@gmx.de>
- update to version 2.2.2:
  * Incompatible changes
    + #6803: For security reason of python, parallel mode is disabled
    on macOS and Python3.8+
  * Bugs fixed
    + #6776: LaTeX: 2019-10-01 LaTeX release breaks
    :file:`sphinxcyrillic.sty`
    + #6815: i18n: French, Hindi, Chinese, Japanese and Korean
    translation messages has been broken
    + #6803: parallel build causes AttributeError on macOS and
    Python3.8
* Fri Nov  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.1:
  * #6641: LaTeX: Undefined control sequence \sphinxmaketitle
  * #6710: LaTeX not well configured for Greek language as main language
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update 2.2.0:
  * apidoc: template files are renamed to ``.rst_t``
  * html: Field lists will be styled by grid layout
  * #5124: graphviz: ``:graphviz_dot:`` option is renamed to ``:layout:``
  * #1464: html: emit a warning if :confval:`html_static_path` and
    :confval:`html_extra_path` directories are inside output directory
  * #6514: html: Add a label to search input for accessability purposes
  * #5602: apidoc: Add ``--templatedir`` option
  * #6475: Add ``override`` argument to ``app.add_autodocumenter()``
  * #6310: imgmath: let :confval:`imgmath_use_preview` work also with the SVG
    format for images rendering inline math
  * #6533: LaTeX: refactor visit_enumerated_list() to use ``\sphinxsetlistlabels``
  * #6628: quickstart: Use ``https://docs.python.org/3/`` for default setting of
    :confval:`intersphinx_mapping`
  * #6419: sphinx-build: give reasons why rebuilded
* Fri Aug  9 2019 Dan Čermák <dcermak@suse.com>
- Add Sphinx translation files via %%find_lang
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.2:
  * #6497: custom lexers fails highlighting when syntax error
  * #6478, #6488: info field lists are incorrectly recognized
* Tue Jun 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.1:
  * #6442: LaTeX: admonitions of note type can get separated from immediately preceding section title by pagebreak
  * #6448: autodoc: crashed when autodocumenting classes with __slots__ = None
  * #6452: autosummary: crashed when generating document of properties
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1:
  * Many major updates in the package
  * Supports only python 3.5+
- Remove obsolete conditionals wrt 3.5+ only support
* Wed Apr 10 2019 Dirk Mueller <dmueller@suse.com>
- don't provide sphinx from test subpackage, it is for testing
* Wed Apr 10 2019 Dirk Mueller <dmueller@suse.com>
- fix tests to include latex/extmath tests
* Wed Mar 27 2019 Matej Cepl <mcepl@suse.com>
- Remove last remainder of python-Sphinx-doc-man-common subpackage
* Thu Mar 14 2019 Matej Cepl <mcepl@suse.com>
- Switch off test_latex_images test, because it tries to download
  image from the www.python.org.
* Tue Mar 12 2019 Matej Cepl <mcepl@suse.com>
- Remove lang packages
* Mon Mar 11 2019 Matej Cepl <mcepl@suse.com>
- Revert to multiple lang files using standard macros.
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop patch disable-test.patch no longer applicable
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.5:
  * LaTeX: Remove extraneous space after author names on PDF title page (refs: #6004)
  * #6026: LaTeX: A cross reference to definition list does not work
  * #6046: LaTeX: TypeError is raised when invalid latex_elements given
  * #6067: LaTeX: images having a target are concatenated to next line
  * #6067: LaTeX: images having a target are not aligned even if specified
  * #6019: imgconverter: Including multipage PDF fails
  * #6047: autodoc: autofunction emits a warning for method objects
  * #6028: graphviz: Ensure the graphviz filenames are reproducible
  * #6068: doctest: skipif option may remove the code block from documentation
  * #6136: :name: option for math directive causes a crash
  * #6139: intersphinx: ValueError on failure reporting
  * #6135: changes: Fix UnboundLocalError when any module found
* Wed Mar  6 2019 Matej Cepl <mcepl@suse.com>
- Rewrite the package to multibuild. Remove python-Sphinx-doc*.
- Fix %%check to make tests passing.
* Tue Mar  5 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 1.8.4:
  There are many changes so have a look at the following changes files:
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-8-4-released-feb-03-2019
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-8-3-released-dec-26-2018
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-8-2-released-nov-11-2018
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-8-1-released-sep-22-2018
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-8-0-released-sep-13-2018
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-7-9-released-sep-05-2018
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-7-8-released-aug-29-2018
  * https://www.sphinx-doc.org/en/master/changes.html#release-1-7-7-released-aug-19-2018
* Fri Dec  7 2018 mcepl@suse.com
- Make this package also own %%{python_sitelib}/sphinxcontrib
  directory, so it is properly owned.
* Wed Jul 18 2018 mimi.vx@gmail.com
- update to 1.7.6
- fix Requires based on results of Shinx testsuite
  * LaTeX \sphinxupquote{} breaks in Russian
  * sphinx.testing uses deprecated pytest API; Node.get_marker(name)
  * crashed when recommonmark.AutoStrictify is enabled
  * latex: crashed with docutils package provided by Debian/Ubuntu
  * latex: a label for table is vanished if table does not have a caption
  * crashed with numbered toctree
  * C, render empty argument lists for macros.
  * C++, fix lookup of full template specializations with no template arguments.
  * C++, fix assertion on missing references in global scope when using intersphinx.
  * autodoc: crashed by Form Feed Character
  * autodoc: loses the first staticmethod parameter for old styled classes
  * quickstart: Typing Ctrl-U clears the whole of line
  * html: “relations” sidebar is not shown by default
  * latex: curly braces in index entries are not handled correctly
  * epub: Wrong internal href fragment links
  * apidoc: Interface of sphinx.apidoc:main() has changed
  * PDF builds of French projects have issues with XeTeX
  * napoleon raises RuntimeError with python 3.7
  * sphinx-build: Interface of sphinx:main() has changed
  * sphinx-build: sphinx.cmd.build.main() refers sys.argv
    instead of given argument
  * autosummary: warning is emitted when the first line of docstring ends
    with literal notation
  * autosummary: warnings of autosummary indicates wrong location (refs: #5146)
  * autodoc: crashed on inspecting dict like object which does not support sorting
  * autodoc: Enum argument missing if it shares value with another
  * py domain: rtype field could not handle “None” as a type
  * LaTeX: indexing of terms containing @, !, or " fails
  * html: crashes if copying static files are failed
  * autodoc: Fix formatting type annotations for tuples with more than two arguments
  * i18n: crashed by auto-symbol footnote references
  * autosummary: module summary has been broken when it starts with heading
* Tue Jul 17 2018 dmueller@suse.com
- update to 1.7.5:
  * #4924: html search: Upper characters problem in any other languages
  * #4932: apidoc: some subpackage is ignored if sibling subpackage contains a
    module starting with underscore
  * #4863, #4938, #4939: i18n doesn't handle node.title correctly tat used for
    contents, topic, admonition, table and section.
  * #4913: i18n: literal blocks in bullet list are not translated
  * #4962: C++, raised TypeError on duplicate declaration.
  * #4825: C++, properly parse expr roles and give better error messages when
    (escaped) line breaks are present.
  * C++, properly use ``desc_addname`` nodes for prefixes of names.
  * C++, parse pack expansions in function calls.
  * #4915, #4916: links on search page are broken when using dirhtml builder
  * #4969: autodoc: constructor method should not have return annotation
  * latex: deeply nested enumerated list which is beginning with non-1 causes
    LaTeX engine crashed
  * #4978: latex: shorthandoff is not set up for Brazil locale
  * #4928: i18n: Ignore dot-directories like .git/ in LC_MESSAGES/
  * #4946: py domain: type field could not handle "None" as a type
  * #4979: latex: Incorrect escaping of curly braces in index entries
  * #4956: autodoc: Failed to extract document from a subclass of the class on
    mocked module
  * #4973: latex: glossary directive adds whitespace to each item
  * #4980: latex: Explicit labels on code blocks are duplicated
  * #4919: node.asdom() crashes if toctree has :numbered: option
  * #4914: autodoc: Parsing error when using dataclasses without default values
  * #4931: autodoc: crashed when handler for autodoc-skip-member raises an error
  * #4931: autodoc: crashed when subclass of mocked class are processed by
    napoleon module
  * #5007: sphinx-build crashes when error log contains a "%%" character
* Wed May 23 2018 mimi.vx@gmail.com
- update to 1.7.4
- very long list of changes - please see http://www.sphinx-doc.org/en/master/changes.html#release-1-7-4-released-apr-25-2018
* Thu Mar  8 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Mar  6 2018 dmueller@suse.com
- go back to a working sphinx version for now (1.6.5)
  * newer versions are not able to build openstack clients
* Tue Feb 27 2018 aplanas@suse.com
- Recommends only on SUSE
* Sat Feb 24 2018 arun@gmx.de
- specfile:
  * update copyright year
  * remove sed for sed command for sphinx/pycode/pgen2/token.py
    (not in tar-ball anymore)
- update to version 1.7.1:
  * Deprecated
    + #4623: "sphinx.build_main()" is deprecated. Use
    "sphinx.cmd.build.build_main()" instead.
    + autosummary: The interface of
    "sphinx.ext.autosummary.get_documenter()" has been changed
    (Since 1.7.0)
    + #4664: "sphinx.ext.intersphinx.debug()" is deprecated. Use
    "sphinx.ext.intersphinx.inspect_main()" instead.
  * Bugs fixed
    + #4608: epub: Invalid meta tag is generated
    + #4260: autodoc: keyword only argument separator is not
    disappeared if it is appeared at top of the argument list
    + #4622: epub: :confval:`epub_scheme` does not effect to
    content.opf
    + #4627: graphviz: Fit graphviz images to page
    + #4617: quickstart: PROJECT_DIR argument is required
    + #4623: sphinx.build_main no longer exists in 1.7.0
    + #4615: The argument of "sphinx.build" has been changed in 1.7.0
    + autosummary: The interface of
    "sphinx.ext.autosummary.get_documenter()" has been changed
    + #4630: Have order on msgids in sphinx.pot deterministic
    + #4563: autosummary: Incorrect end of line punctuation detection
    + #4577: Enumerated sublists with explicit start with wrong number
    + #4641: A external link in TOC cannot contain "?" with ":glob:"
    option
    + C++, add missing parsing of explicit casts and typeid in
    expression parsing.
    + C++, add missing parsing of "this" in expression parsing.
    + #4655: Fix incomplete localization strings in Polish
    + #4653: Fix error reporting for parameterless ImportErrors
    + #4664: Reading objects.inv fails again
    + #4662: "any" refs with "term" targets crash when an ambiguity is
    encountered
- changes to version 1.7.0:
  * long changelog, see https://github.com/sphinx-doc/sphinx/blob/master/CHANGES
- changes from version 1.6.7:
  * Bugs fixed
    + #1922: html search: Upper characters problem in French
    + #4412: Updated jQuery version from 3.1.0 to 3.2.1
    + #4438: math: math with labels with whitespace cause html error
    + #2437: make full reference for classes, aliased with "alias of"
    + #4434: pure numbers as link targets produce warning
    + #4477: Build fails after building specific files
    + #4449: apidoc: include "empty" packages that contain modules
    + #3917: citation labels are tranformed to ellipsis
    + #4501: graphviz: epub3 validation error caused if graph is not
    clickable
    + #4514: graphviz: workaround for wrong map ID which graphviz
    generates
    + #4525: autosectionlabel does not support parallel build
    + #3953: Do not raise warning when there is a working intersphinx
    inventory
    + #4487: math: ValueError is raised on parallel build. Thanks to
    jschueller.
    + #2372: autosummary: invalid signatures are shown for type
    annotated functions
    + #3942: html: table is not aligned to center even if ":align:
    center"
- changes from version 1.6.6:
  * Features added
    + #4181: autodoc: Sort dictionary keys when possible
    + "VerbatimHighlightColor" is a new :ref:`LaTeX 'sphinxsetup'
    <latexsphinxsetup>` key (refs: #4285)
    + Easier customizability of LaTeX macros involved in rendering of
    code-blocks
    + Show traceback if conf.py raises an exception (refs: #4369)
    + Add :confval:`smartquotes` to disable smart quotes through
    "conf.py" (refs: #3967)
    + Add :confval:`smartquotes_action` and
    :confval:`smartquotes_excludes` (refs: #4142, #4357)
  * Bugs fixed
    + #4334: sphinx-apidoc: Don't generate references to non-existing
    files in TOC
    + #4206: latex: reST label between paragraphs loses paragraph
    break
    + #4231: html: Apply fixFirefoxAnchorBug only under Firefox
    + #4221: napoleon depends on autodoc, but users need to load it
    manually
    + #2298: automodule fails to document a class attribute
    + #4099: C++: properly link class reference to class from inside
    constructor
    + #4267: PDF build broken by Unicode U+2116 NUMERO SIGN character
    + #4249: PDF output: Pygments error highlighting increases line
    spacing in code blocks
    + #1238: Support ":emphasize-lines:" in PDF output
    + #4279: Sphinx crashes with pickling error when run with multiple
    processes and remote image
    + #1421: Respect the quiet flag in sphinx-quickstart
    + #4281: Race conditions when creating output directory
    + #4315: For PDF 'howto' documents,
    "latex_toplevel_sectioning='part'" generates "\chapter"
    commands
    + #4214: Two todolist directives break sphinx-1.6.5
    + Fix links to external option docs with intersphinx (refs: #3769)
    + #4091: Private members not documented without :undoc-members:
* Fri Oct 27 2017 arun@gmx.de
- update to version 1.6.5:
  * Features added
    + #4107: Make searchtools.js compatible with pre-Sphinx1.5
    templates
    + #4112: Don't override the smart_quotes setting if it was already
    set
    + #4125: Display reference texts of original and translated
    passages on i18n warning message
    + #4147: Include the exception when logging PO/MO file read/write
  * Bugs fixed
    + #4085: Failed PDF build from image in parsed-literal using
    ":align:" option
    + #4100: Remove debug print from autodoc extension
    + #3987: Changing theme from alabaster causes HTML build to fail
    + #4096: C++, don't crash when using the wrong role type. Thanks
    to mitya57.
    + #4070, #4111: crashes when the warning message contains format
    strings (again)
    + #4108: Search word highlighting breaks SVG images
    + #3692: Unable to build HTML if writing .buildinfo failed
    + #4152: HTML writer crashes if a field list is placed on top of
    the document
    + #4063: Sphinx crashes when labeling directive ".. todolist::"
    + #4134: [doc] :file:`docutils.conf` is not documented explicitly
    + #4169: Chinese language doesn't trigger Chinese search
    automatically
    + #1020: ext.todo todolist not linking to the page in pdflatex
    + #3965: New quickstart generates wrong SPHINXBUILD in Makefile
    + #3739: ":module:" option is ignored at content of pyobjects
    + #4149: Documentation: Help choosing :confval:`latex_engine`
    + #4090: [doc] :confval:`latex_additional_files` with extra LaTeX
    macros should not use ".tex" extension
    + Failed to convert reST parser error to warning (refs: #4132)
* Sat Sep 30 2017 arun@gmx.de
- update to version 1.6.4:
  * Features added
    + #3926: Add "autodoc_warningiserror" to suppress the behavior of
    "-W" option during importing target modules on autodoc
  * Bugs fixed
    + #3924: docname lost after dynamically parsing RST in extension
    + #3946: Typo in sphinx.sty (this was a bug with no effect in
    default context)
    + :pep: and :rfc: does not supports "default-role" directive
    (refs: #3960)
    + #3960: default_role = 'guilabel' not functioning
    + Missing "texinputs_win/Makefile" to be used in latexpdf builder
    on windows.
    + #4026: nature: Fix macOS Safari scrollbar color
    + #3877: Fix for C++ multiline signatures.
    + #4006: Fix crash on parallel build
    + #3969: private instance attributes causes AttributeError
    + #4041: C++, remove extra name linking in function pointers.
    + #4038: C, add missing documentation of "member" role.
    + #4044: An empty multicolumn cell causes extra row height in PDF
    output
    + #4049: Fix typo in output of sphinx-build -h
    + #4062: hashlib.sha1() must take bytes, not unicode on Python 3
    + Avoid indent after index entries in latex (refs: #4066)
    + #4070: crashes when the warning message contains format strings
    + #4067: Return non-zero exit status when make subprocess fails
    + #4055: graphviz: the :align: option does not work for SVG output
    + #4055: graphviz: the :align: center option does not work for
    latex output
    + #4051: "warn()" function for HTML theme outputs 'None' string
* Mon Sep 18 2017 toddrme2178@gmail.com
- Move sphinxcontrib namespace into seperate package to avoid
  dependency loop with sphinxcontrib-websupport.
* Mon Sep 11 2017 jengelh@inai.de
- Trim package descriptions for size.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Create a base sphinxcontrib namespace package to guarantee all
  the "python(2|3)-sphinxcontrib-foo" packages can be imported
  correctly.
* Thu Aug 24 2017 toddrme2178@gmail.com
- Add new latex dependencies needed in openSUSE:Factory
* Mon Jul 24 2017 toddrme2178@gmail.com
- Split documentation into subpackage to avoid dependency loops.
- Only require python3-typing for python3 < 3.5
* Mon Jul  3 2017 tbechtold@suse.com
- update to 1.6.3:
  * #3821: Failed to import sphinx.util.compat with docutils-0.14rc1
  * #3829: sphinx-quickstart template is incomplete regarding use of alabaster
  * #3772: 'str object' has no attribute 'filename'
  * Emit wrong warnings if citation label includes hyphens (refs: #3565)
  * #3858: Some warnings are not colored when using --color option
  * #3775: Remove unwanted whitespace in default template
  * #3835: sphinx.ext.imgmath fails to convert SVG images if project directory
  name contains spaces
  * #3850: Fix color handling in make mode's help command
  * #3865: use of self.env.warn in sphinx extension fails
  * #3824: production lists apply smart quotes transform since Sphinx 1.6.1
  * latex: fix ``\sphinxbfcode`` swallows initial space of argument
  * #3878: Quotes in auto-documented class attributes should be straight quotes
  in PDF output
  * #3881: LaTeX figure floated to next page sometimes leaves extra vertical
  whitespace
  * #3885: duplicated footnotes raises IndexError
  * #3873: Failure of deprecation warning mechanism of
  ``sphinx.util.compat.Directive``
  * #3874: Bogus warnings for "citation not referenced" for cross-file citations
  * #3860: Don't download images when builders not supported images
  * #3860: Remote image URIs without filename break builders not supported remote
  images
  * #3833: command line messages are translated unintentionally with ``language``
  setting.
  * #3840: make checking ``epub_uid`` strict
  * #3851, #3706: Fix about box drawing characters for PDF output
  * #3900: autosummary could not find methods
  * #3902: Emit error if ``latex_documents`` contains non-unicode string in py2
* Fri Jun 30 2017 tbechtold@suse.com
- python-sphinxcontrib-websupport is a Requires
* Thu Jun 29 2017 tbechtold@suse.com
- Adjust Requires
* Fri Jun 23 2017 tbechtold@suse.com
- update to 1.6.2:
  * See http://www.sphinx-doc.org/en/stable/changes.html
- Adjust Requires and BuildRequires
- Add disable-test.patch to disable test which needs remote access.
* Mon May  8 2017 toddrme2178@gmail.com
- Fix update-alternatives.
* Fri May  5 2017 toddrme2178@gmail.com
- Fix old obsoletes/provides.
* Mon Feb 20 2017 jmatejek@suse.com
- update for singlespec
- run tests for all python versions
- include python-enum34 for test compatibility
* Thu Feb 16 2017 tbechtold@suse.com
- update to 1.5.2:
  * See http://www.sphinx-doc.org/en/stable/changes.html
- Adjust Requires and BuildRequires
* Mon Feb 29 2016 michael@stroeder.com
- Removed obsolete fix_some_testcase_error_with_pygments-2.1.1.patch
- update to version 1.3.6:
  * #1873, #1876, #2278: Add ``page_source_suffix`` html context variable. This should be
    introduced with :confval:`source_parsers` feature. Thanks for Eric Holscher.
  * #2265: Fix babel is used in spite of disabling it on ``latex_elements``
  * #2295: Avoid mutating dictionary errors while enumerating members in autodoc
    with Python 3
  * #2291: Fix pdflatex "Counter too large" error from footnotes inside tables of contents
  * #2292: Fix some footnotes disappear from LaTeX output
  * #2287: ``sphinx.transforms.Locale`` always uses rst parser. Sphinx i18n feature should
    support parsers that specified source_parsers.
  * #2290: Fix ``sphinx.ext.mathbase`` use of amsfonts may break user choice of math fonts
  * #2324: Print a hint how to increase the recursion limit when it is hit.
  * #1565, #2229: Revert new warning; the new warning will be triggered from version 1.4 on.
  * #2329: Refresh environment forcely if source directory has changed.
  * #2019: Fix the domain objects in search result are not escaped
* Wed Feb 17 2016 toddrme2178@gmail.com
- Add fix_some_testcase_error_with_pygments-2.1.1.patch
  Fixes tests with python-Pygments 2.1.1.
  Should be in next release.
  See https://github.com/sphinx-doc/sphinx/commit/50f4862b069d58ade556aad90bd179206f10fdc1
- Add additional latex requirements.
* Mon Jan 25 2016 michael@stroeder.com
- requires python-pygments => 2.1
- update to version 1.3.5:
  * Fix line numbers was not shown on warnings in LaTeX and texinfo
    builders
  * Fix filenames were not shown on warnings of citations
  * Fix line numbers was not shown on warnings in LaTeX and texinfo
    builders
  * Fix line numbers was not shown on warnings of indecies
  * #2026: Fix LaTeX builder rais error if parsed-literal includes
    links
  * #2243: Ignore strange docstring types for classes, do not crash
  * #2247: Fix #2205 breaks make html for definition list with
    classifiers that contains regular-expression like string
  * #1565: Show warning if Pygments throws an ErrorToken
  * #2211: Fix paragraphs in table cell doesn't work in Latex output
  * #2253: ":pyobject:" option of "literalinclude" directive can't
    detect indented body block when the block starts with blank or
    comment lines.
  * Fix TOC is not shown when no ":maxdepth:" for toctrees (ref: #771)
  * Fix warning message for ":numref:" if target is in orphaned doc
    (ref: #2244)
* Tue Jan 12 2016 michael@stroeder.com
- Update to 1.3.4
  Release 1.3.4 (released Jan 12, 2016)[51]
  * #2134: Fix figure caption with reference causes latex build error
  * #2094: Fix rubric with reference not working in Latex
  * #2147: Fix litralinclude code in latex does not break in pages
  * #1833: Fix email addresses is showed again if latex_show_urls is
  not None
  * #2176: sphinx.ext.graphviz: use <object> instead of <img> to embed
  svg
  * #967: Fix SVG inheritance diagram is not hyperlinked (clickable)
  * #1237: Fix footnotes not working in definition list in LaTeX
  * #2168: Fix raw directive does not work for text writer
  * #2171: Fix cannot linkcheck url with unicode
  * #2182: LaTeX: support image file names with more than 1 dots
  * #2189: Fix previous sibling link for first file in subdirectory
  uses last file, not intended previous from root toctree
  * #2003: Fix decode error under python2 (only) when make linkcheck is
  run
  * #2186: Fix LaTeX output of mathbb in math
  * #1480, #2188: LaTeX: Support math in section titles
  * #2071: Fix same footnote in more than two section titles =>
  LaTeX/PDF Bug
  * #2040: Fix UnicodeDecodeError in sphinx-apidoc when author contains
  non-ascii characters
  * #2193: Fix shutil.SameFileError if source directory and destination
  directory are same
  * #2178: Fix unparseable C++ cross-reference when referencing a
  function with :cpp:any:
  * #2206: Fix Sphinx latex doc build failed due to a footnotes
  * #2201: Fix wrong table caption for tables with over 30 rows
  * #2213: Set <blockquote> in the classic theme to fit with <p>
  * #1815: Fix linkcheck does not raise an exception if warniserror set
  to true and link is broken
  * #2197: Fix slightly cryptic error message for missing index.rst
  file
  * #1894: Unlisted phony targets in quickstart Makefile
  * #2125: Fix unifies behavior of collapsed fields (GroupedField and
  TypedField)
  * #1408: Check latex_logo validity before copying
  * #771: Fix latex output doesn’t set tocdepth
  * #1820: On Windows, console coloring is broken with colorama version
  0.3.3. Now sphinx use colorama>=0.3.5 to avoid this problem.
  * #2072: Fix footnotes in chapter-titles do not appear in PDF output
  * #1580: Fix paragraphs in longtable don’t work in Latex output
  * #1366: Fix centered image not centered in latex
  * #1860: Fix man page using :samp: with braces - font doesn’t reset
  * #1610: Sphinx crashes in japanese indexing in some systems
  * Fix Sphinx crashes if mecab initialization failed
  * #2160: Fix broken TOC of PDFs if section includes an image
  * #2172: Fix dysfunctional admonition [53]py@lightbox in sphinx.sty.
  Thanks to jfbu.
  * #2198,#2205: make gettext generate broken msgid for definition
  lists.
  * #2062: Escape characters in doctests are treated incorrectly with
  Python 2.
  * #2225: Fix if the option does not begin with dash, linking is not
  performed
  * #2226: Fix math is not HTML-encoded when :nowrap: is given (jsmath,
  mathjax)
  * #1601, #2220: ‘any’ role breaks extended domains behavior. Affected
  extensions doesn’t support resolve_any_xref and resolve_xref
  returns problematic node instead of None. sphinxcontrib-httpdomain
  is one of them.
  * #2229: Fix no warning is given for unknown options
* Wed Dec  9 2015 michael@stroeder.com
- Update to 1.3.3
- Updated project url in .spec file
- Aligned version in BuildRequires: python-Pygments >= 2.0 with
  Requires line
  Release 1.3.3 (released Dec 2, 2015)
  Bugs fixed
----------
  * #2012: Fix exception occurred if ``numfig_format`` is invalid
  * #2142: Provide non-minified JS code in ``sphinx/search/non-minified-js/*.js`` for
  source distribution on PyPI.
  * #2148: Error while building devhelp target with non-ASCII document.
  Release 1.3.2 (released Nov 29, 2015)
  Features added
  * #1935: Make "numfig_format" overridable in latex_elements.
  Bugs fixed
----------
  * #1976: Avoid "2.0" version of Babel because it doesn't work with Windows environment.
  * Add a "default.css" stylesheet (which imports "classic.css") for compatibility.
  * #1788: graphviz extension raises exception when caption option is present.
  * #1789: ``:pyobject:`` option of ``literalinclude`` directive includes following
  lines after class definitions
  * #1790: ``literalinclude`` strips empty lines at the head and tail
  * #1802: load plugin themes automatically when theme.conf use it as 'inherit'. Thanks to
  Takayuki Hirai.
  * #1794: custom theme extended from alabaster or sphinx_rtd_theme can't find base theme.
  * #1834: compatibility for docutils-0.13: handle_io_errors keyword argument for
  docutils.io.FileInput cause TypeError.
  * #1823: '.' as <module_path> for sphinx-apidoc cause an unfriendly error. Now '.'
  is converted to absolute path automatically.
  * Fix a crash when setting up extensions which do not support metadata.
  * #1784: Provide non-minified JS code in ``sphinx/search/non-minified-js/*.js``
  * #1822, #1892: Fix regression for #1061. autosummary can't generate doc for imported
  members since sphinx-1.3b3. Thanks to Eric Larson.
  * #1793, #1819: "see also" misses a linebreak in text output. Thanks to Takayuki Hirai.
  * #1780, #1866: "make text" shows "class" keyword twice. Thanks to Takayuki
  Hirai.
  * #1871: Fix for LaTeX output of tables with one column and multirows.
  * Work around the lack of the HTMLParserError exception in Python 3.5.
  * #1949: Use ``safe_getattr`` in the coverage builder to avoid aborting with
  descriptors that have custom behavior.
  * #1915: Do not generate smart quotes in doc field type annotations.
  * #1796: On py3, automated .mo building caused UnicodeDecodeError.
  * #1923: Use babel features only if the babel latex element is nonempty.
  * #1942: Fix a KeyError in websupport.
  * #1903: Fix strange id generation for glossary terms.
  * #1796, On py3, automated .mo building cause UnicodeDecodeError
  * Fix: ``make text`` will crush if a definition list item has more than 1 classifiers as:
  * #1796: On py3, automated .mo building cause UnicodeDecodeError
  * ``make text`` will crush if a definition list item has more than 1 classifiers as:
  * Fixed #1855: make gettext generates broken po file for definition lists with classifier.
  ``term : classifier1 : classifier2``.
  * #1855: make gettext generates broken po file for definition lists with classifier.
  * #1869: Fix problems when dealing with files containing non-ASCII characters. Thanks to
  Marvin Schmidt.
  * #1798: Fix building LaTeX with references in titles.
  * #1725: On py2 environment, doctest with using non-ASCII characters causes
  ``'ascii' codec can't decode byte`` exception.
  * #1540: Fix RuntimeError with circular referenced toctree
  * #1983: i18n translation feature breaks references which uses section name.
  * #1990: Use caption of toctree to title of \tableofcontents in LaTeX
  * #1987: Fix ampersand is ignored in ``:menuselection:`` and ``:guilabel:`` on LaTeX builder
  * #1994: More supporting non-standard parser (like recommonmark parser) for Translation and
  WebSupport feature. Now node.rawsource is fall backed to node.astext() during docutils
  transforming.
  * On Py2 environment, conf.py that is generated by sphinx-quickstart should have u prefixed
  config value for 'version' and 'release'.
  * #2102: On Windows + Py3, using ``|today|`` and non-ASCII date format will raise
  UnicodeEncodeError.
  * #1974: UnboundLocalError: local variable 'domain' referenced before assignment when
  using `any` role and `sphinx.ext.intersphinx` in same time.
  * #2121: multiple words search doesn't find pages when words across on the page title and
  the page content.
  * #1884, #1885: plug-in html themes cannot inherit another plug-in theme. Thanks to
  Suzumizaki.
  * #1818: `sphinx.ext.todo` directive generates broken html class attribute as
  'admonition-' when :confval:`language` is specified with non-ASCII linguistic area like
  'ru' or 'ja'. To fix this, now ``todo`` directive can use ```:class:`` option.
  * #2140: Fix footnotes in table has broken in LaTeX
  * #2127: MecabBinder for html searching feature doesn't work with Python 3.
  Thanks to Tomoko Uchida.
* Wed Sep 16 2015 toddrme2178@gmail.com
- Don't buildrequires latex-related stuff.
* Fri Sep  4 2015 toddrme2178@gmail.com
- Split latex-related stuff into its own subpackage so we can
  depend on the necessary latex components.
* Wed Jul 29 2015 hpj@urpla.net
- Be explicit about six version requirements
* Mon Jul 27 2015 seife+obs@b1-systems.com
- fix build on CentOS/RHEL by conditionalizing Recommends: tag
- add #!BuildIgnore: texinfo to work around CentOS-7 project config
* Mon Jun 29 2015 toddrme2178@gmail.com
- Fix directory for man update-alternatives
- Suggests are poorly-supported in openSUSE so use Recommends
* Mon Apr 13 2015 alarrosa@suse.com
- Added python-six as a requirement, not only as build requirement
* Thu Apr  9 2015 termim@gmail.com
- Update to 1.3.1
  + Bugs fixed
  * see http://sphinx-doc.org/changes.html#release-1-3-1-released-mar-17-2015
    for complete list of fixed bugs
- additional dependencies required by 1.3.1
  + python-Babel
  + python-alabaster
  + python-snowballstemmer
  + python-sphinx_rtdtheme
  + python-mock
  + python-six
- Update to 1.3
  + Incompatible changes
  * Roles ref, term and menusel now don’t generate emphasis nodes
    anymore. If you want to keep italic style, adapt your stylesheet.
  * Role numref uses %%s as special character to indicate position of
    figure numbers instead # symbol.
  * Dependency requirement updates: docutils 0.11, Pygments 2.0
  * The gettext_enables config value has been renamed to
    gettext_additional_targets.
  * #1735: Use https://doc.python.org/ instead of http protocol. It was
    used for sphinx.ext.intersphinx and some documentation.
  * update bundled ez_setup.py for setuptools-7.0 that requires Python
    2.6 or later.
  * Dropped support for Python 2.5, 3.1 and 3.2.
  * Dropped support for docutils versions up to 0.9.
  * Removed the sphinx.ext.oldcmarkup extension.
  * The deprecated config values exclude_trees, exclude_dirnames and
    unused_docs have been removed.
  * A new node, sphinx.addnodes.literal_strong, has been added, for text
    that should appear literally (i.e. no smart quotes) in strong
    font. Custom writers will have to be adapted to handle this node.
  * PR#269, #1476: replace <tt> tag by <code>. User customized
    stylesheets should be updated If the css contain some styles for tt>
    tag. Thanks to Takeshi Komiya.
  * #1543: templates_path is automatically added to exclude_patterns to
    avoid reading autosummary rst templates in the templates directory.
  * Custom domains should implement the new Domain.resolve_any_xref
    method to make the any role work properly.
  * gettext builder: gettext doesn’t emit uuid information to generated
    pot files by default. Please set True to gettext_uuid to emit uuid
    information. Additionally, if the python-levenshtein 3rd-party package is
    installed, it will improve the calculation time.
  * gettext builder: disable extracting/apply ‘index’ node by
    default. Please set ‘index’ to gettext_enables to enable extracting index
    entries.
  * PR#307: Add frame to code-block in LaTeX. Thanks to Takeshi Komiya.
  + Features added
  * Add convenience directives and roles to the C++ domain: directive
    cpp:var as alias for cpp:member, role :cpp:var as alias for :cpp:member,
    and role any for cross-reference to any C++ declaraction. #1577, #1744
  * The source_suffix config value can now be a list of multiple suffixes.
  * Add the ability to specify source parsers by source suffix with the
    source_parsers config value.
  * #1675: A new builder, AppleHelpBuilder, has been added that builds
    Apple Help Books.
  * #1346: Add new default theme;
    Add ‘alabaster’ theme.
    Add ‘sphinx_rtd_theme’ theme.
    The ‘default’ html theme has been renamed to ‘classic’. ‘default’
    is still available, however it will emit notice a recommendation that
    using new ‘alabaster’ theme.
  * Added highlight_options configuration value.
  * The language config value is now available in the HTML templates.
  * The env-updated event can now return a value, which is interpreted as
    an iterable of additional docnames that need to be rewritten.
  * #772: Support for scoped and unscoped enums in C++. Enumerators in
    unscoped enums are injected into the parent scope in addition to the enum
    scope.
  * Add todo_include_todos config option to quickstart conf file, handled
    as described in documentation.
  * HTML breadcrumb items tag has class “nav-item” and “nav-item-N” (like
    nav-item-0, 1, 2...).
  * New option sphinx-quickstart --use-make-mode for generating Makefile
    that use sphinx-build make-mode.
  * #1235: i18n: several node can be translated if it is set to
    gettext_additional_targets in conf.py. Supported nodes are:
    ‘literal-block’
    ‘doctest-block’
    ‘raw’
    ‘image’
  * #1227: Add html_scaled_image_link config option to conf.py, to
    control scaled image link.
  * #1597: Added possibility to return a new template name from
    html-page-context.
  * PR#314, #1150: Configuration values are now checked for their type. A
    warning is raised if the configured and the default value do not have the
    same type and do not share a common non-trivial base class.
  * Add support for Python 3.4.
  * Add support for docutils 0.12
  * Added sphinx.ext.napoleon extension for NumPy and Google style
    docstring support.
  * Added support for parallel reading (parsing) of source files with the
    sphinx-build -j option. Third-party extensions will need to be checked
    for compatibility and may need to be adapted if they store information in
    the build environment object. See env-merge-info.
  * Added the any role that can be used to find a cross-reference of any
    type in any domain. Custom domains should implement the new
    Domain.resolve_any_xref method to make this work properly.
  * Exception logs now contain the last 10 messages emitted by Sphinx.
  * Added support for extension versions (a string returned by setup(),
    these can be shown in the traceback log files). Version requirements for
    extensions can be specified in projects using the new needs_extensions
    config value.
  * Changing the default role within a document with the default-role
    directive is now supported.
  * PR#214: Added stemming support for 14 languages, so that the built-in
    document search can now handle these. Thanks to Shibukawa Yoshiki.
  * PR#296, PR#303, #76: numfig feature: Assign numbers to figures,
    tables and code-blocks. This feature is configured with numfig,
    numfig_secnum_depth and numfig_format. Also numref role is
    available. Thanks to Takeshi Komiya.
  * PR#202: Allow ”.” and “~” prefixed references in :param: doc fields
    for Python.
  * PR#184: Add autodoc_mock_imports, allowing to mock imports of
    external modules that need not be present when autodocumenting.
  * #925: Allow list-typed config values to be provided on the command
    line, like -D key=val1,val2.
  * #668: Allow line numbering of code-block and literalinclude
    directives to start at an arbitrary line number, with a new lineno-start
    option.
  * PR#172, PR#266: The code-block and literalinclude directives now can
    have a caption option that shows a filename before the code in the
    output. Thanks to Nasimul Haque, Takeshi Komiya.
  * Prompt for the document language in sphinx-quickstart.
  * PR#217: Added config values to suppress UUID and location information
    in generated gettext catalogs.
  * PR#236, #1456: apidoc: Add a -M option to put module documentation
    before submodule documentation. Thanks to Wes Turner and Luc Saffre.
  * #1434: Provide non-minified JS files for jquery.js and underscore.js
    to clarify the source of the minified files.
  * PR#252, #1291: Windows color console support. Thanks to meu31.
  * PR#255: When generating latex references, also insert latex
    target/anchor for the ids defined on the node. Thanks to Olivier
    Heurtier.
  * PR#229: Allow registration of other translators. Thanks to Russell
    Sim.
  * Add app.set_translator() API to register or override a Docutils
    translator class like html_translator_class.
  * PR#267, #1134: add ‘diff’ parameter to literalinclude. Thanks to
    Richard Wall and WAKAYAMA shirou.
  * PR#272: Added ‘bizstyle’ theme. Thanks to Shoji KUMAGAI.
  * Automatically compile *.mo files from *.po files when
    gettext_auto_build is True (default) and *.po is newer than *.mo file.
  * #623: sphinx.ext.viewcode supports imported function/class aliases.
  * PR#275: sphinx.ext.intersphinx supports multiple target for the
    inventory. Thanks to Brigitta Sipocz.
  * PR#261: Added the env-before-read-docs event that can be connected to
    modify the order of documents before they are read by the environment.
  * #1284: Program options documented with option can now start with +.
  * PR#291: The caption of code-block is recognised as a title of ref
    target. Thanks to Takeshi Komiya.
  * PR#298: Add new API: add_latex_package(). Thanks to Takeshi Komiya.
  * #1344: add gettext_enables to enable extracting ‘index’ to gettext
    catalog output / applying translation catalog to generated
    documentation.
  * PR#301, #1583: Allow the line numbering of the directive
    literalinclude to match that of the included file, using a new
    lineno-match option. Thanks to Jeppe Pihl.
  * PR#299: add various options to sphinx-quickstart. Quiet mode option
  - -quiet will skips wizard mode. Thanks to WAKAYAMA shirou.
  * #1623: Return types specified with :rtype: are now turned into links
    if possible.
  + Bugs fixed
  * see http://sphinx-doc.org/changes.html#release-1-3-released-mar-10-2015
    for complete list of fixed bugs
* Tue Sep  9 2014 toddrme2178@gmail.com
- Update to 1.2.3:
  + Features added
  * #1518: `sphinx-apidoc` command now have a `--version` option to show version
    information and exit
  * New locales: Hebrew, European Portuguese, Vietnamese.
  + Bugs fixed
  * #636: Keep straight single quotes in literal blocks in the LaTeX build.
  * #1419: Generated i18n sphinx.js files are missing message catalog entries
    from '.js_t' and '.html'. The issue was introduced from Sphinx-1.1
  * #1363: Fix i18n: missing python domain's cross-references with currentmodule
    directive or currentclass directive.
  * #1444: autosummary does not create the description from attributes docstring.
  * #1457: In python3 environment, make linkcheck cause "Can't convert 'bytes'
    object to str implicitly" error when link target url has a hash part.
    Thanks to Jorge_C.
  * #1467: Exception on Python3 if nonexistent method is specified by automethod
  * #1441: autosummary can't handle nested classes correctly.
  * #1499: With non-callable `setup` in a conf.py, now sphinx-build emits
    user-friendly error message.
  * #1502: In autodoc, fix display of parameter defaults containing backslashes.
  * #1226: autodoc, autosummary: importing setup.py by automodule will invoke
    setup process and execute `sys.exit()`. Now sphinx avoids SystemExit
    exception and emits warnings without unexpected termination.
  * #1503: py:function directive generate incorrectly signature when specifying
    a default parameter with an empty list `[]`. Thanks to Geert Jansen.
  * #1508: Non-ASCII filename raise exception on make singlehtml, latex, man,
    texinfo and changes.
  * #1531: On Python3 environment, docutils.conf with 'source_link=true' in the
    general section cause type error.
  * PR#270, #1533: Non-ASCII docstring cause UnicodeDecodeError when uses with
    inheritance-diagram directive. Thanks to WAKAYAMA shirou.
  * PR#281, PR#282, #1509: TODO extension not compatible with websupport. Thanks
    to Takeshi Komiya.
  * #1477: gettext does not extract nodes.line in a table or list.
  * #1544: `make text` generate wrong table when it has empty table cells.
  * #1522: Footnotes from table get displayed twice in LaTeX. This problem has
    been appeared from Sphinx-1.2.1 by #949.
  * #508: Sphinx every time exit with zero when is invoked from setup.py command.
    ex. `python setup.py build_sphinx -b doctest` return zero even if doctest
    failed.
* Thu Mar  6 2014 mcihar@suse.cz
- Update to 1.2.2:
  - PR#211: When checking for existence of the html_logo file, check the full
    relative path and not the basename.
  - PR#212: Fix traceback with autodoc and __init__ methods without docstring.
  - PR#213: Fix a missing import in the setup command.
  - #1357: Option names documented by option are now again allowed to not start
    with a dash or slash, and referencing them will work correctly.
  - #1358: Fix handling of image paths outside of the source directory when
    using the “wildcard” style reference.
  - #1374: Fix for autosummary generating overly-long summaries if first line
    doesn’t end with a period.
  - #1383: Fix Python 2.5 compatibility of sphinx-apidoc.
  - #1391: Actually prevent using “pngmath” and “mathjax” extensions at the
    same time in sphinx-quickstart.
  - #1386: Fix bug preventing more than one theme being added by the entry
    point mechanism.
  - #1370: Ignore “toctree” nodes in text writer, instead of raising.
  - #1364: Fix ‘make gettext’ fails when the ‘.. todolist::’ directive is
    present.
  - #1367: Fix a change of PR#96 that break
    sphinx.util.docfields.Field.make_field interface/behavior for item argument
    usage.
* Mon Feb 10 2014 speilicke@suse.com
- Update to version 1.2.1
  + See CHANGES
- Fix update-alternatives usage
- Removed sphinx-setup_command_unicode.patch (upstream)
* Mon Nov 18 2013 speilicke@suse.com
- Fix %%preun update-alternatives, used wrong master
* Fri Nov 15 2013 speilicke@suse.com
- Only ghost /etc/alternatives on 12.3 or newer
* Wed Nov 13 2013 speilicke@suse.com
- Add sphinx-setup_command_unicode.patch: Backport of
  https://bitbucket.org/birkenfeld/sphinx/pull-request/193/
* Wed Nov  6 2013 speilicke@suse.com
- Updateo version 1.2b3:
  + The Sphinx error log files will now include a list of the loaded extensions
    for help in debugging.
  + PR#154: Remove "sphinx" prefix from LaTeX class name except 'sphinxmanual'
    and 'sphinxhowto'. Now you can use your custom document class without
    'sphinx' prefix. Thanks to Erik B.
  + #1265: Fix i18n: crash when translating a section name that is pointed to from
    a named target.
  + A wrong condition broke the search feature on first page that is usually
    index.rst.  This issue was introduced in 1.2b1.
  + #703: When Sphinx can't decode filenames with non-ASCII characters, Sphinx now
    catches UnicodeError and will continue if possible instead of raising the
    exception.
- Changes from version 1.2b2 and prior:
  + See CHANGES file
- Own /etc/alternatives/sphinx-* by ghosting (update-alternatives)
- Dropped sphinx-docutils-0.10.patch (merged upstream)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jul 18 2013 speilicke@suse.com
- Drop runtime req on python-distribute
* Tue Jul  9 2013 dmueller@suse.com
- add sphinx-docutils-0.10.patch:
  * add support for docutils 0.10
* Thu May 16 2013 speilicke@suse.com
- Fix update-alternatives and support upgrade from previous versions
* Tue Apr 30 2013 speilicke@suse.com
- Apply update-alternatives for binaries and man-pages
* Tue Nov 20 2012 saschpe@suse.de
- Run testsuite
- Build and install man-pages
* Thu Nov 15 2012 saschpe@suse.de
- Revert last "locale" change, it was a false positive
* Tue Nov  6 2012 saschpe@suse.de
- Remove obsolete SUSE version checks
- Don't package locale files twice
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
* Wed May 23 2012 saschpe@suse.de
- Update to version 1.1.13:
  * PR#40: Fix safe_repr function to decode bytestrings with non-ASCII
    characters correctly.
  * PR#37: Allow configuring sphinx-apidoc via SPHINX_APIDOC_OPTIONS.
  * PR#34: Restore Python 2.4 compatibility.
  * PR#36: Make the "bibliography to TOC" fix in LaTeX output specific to
    the document class.
  * #695: When the highlight language "python" is specified explicitly,
    do not try to parse the code to recognize non-Python snippets.
  * #859: Fix exception under certain circumstances when not finding
    appropriate objects to link to.
  * #860: Do not crash when encountering invalid doctest examples, just
    emit a warning.
  * #864: Fix crash with some settings of :confval:modindex_common_prefix.
  * #862: Fix handling of -D and -A options on Python 3.
  * #851: Recognize and warn about circular toctrees, instead of running
    into recursion errors.
  * #853: Restore compatibility with docutils trunk.
  * #852: Fix HtmlHelp index entry links again.
  * #854: Fix inheritance_diagram raising attribute errors on builtins.
  * #832: Fix crashes when putting comments or lone terms in a glossary.
  * #834, #818: Fix HTML help language/encoding mapping for all Sphinx
    supported languages.
  * #844: Fix crashes when dealing with Unicode output in doctest extension.
  * #831: Provide --project flag in setup_command as advertised.
  * #875: Fix reading config files under Python 3.
  * #876: Fix quickstart test under Python 3.
  * #870: Fix spurious KeyErrors when removing documents.
  * #892: Fix single-HTML builder misbehaving with the master document in a
    subdirectory.
  * #873: Fix assertion errors with empty only directives.
  * #816: Fix encoding issues in the Qt help builder.
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 1.1.2:
  * #809: Include custom fixers in the source distribution.
- Changes from version 1.1.1:
  * #791: Fix QtHelp, DevHelp and HtmlHelp index entry links.
  * #792: Include "sphinx-apidoc" in the source distribution.
  * #797: Don't crash on a misformatted glossary.
  * #801: Make intersphinx work properly without SSL support.
  * #805: Make the Sphinx.add_index_to_domain method work correctly.
  * #780: Fix Python 2.5 compatibility.
* Thu Sep 22 2011 saschpe@suse.de
- Require python-docutils instead of docutils
- Change license to BSD-2-Clause (SPDX style, according to LICENSE)
* Wed Aug 31 2011 saschpe@suse.de
- Corrected buildrequires/requires:
  * python-jinja2 is now python-Jinja2
  * python-pygments is now python-Pygments
* Tue Jul 12 2011 mcihar@suse.cz
- add python-distribute to Requires, it is needed to run sphinx-build
* Sun Jul  3 2011 saschpe@gmx.de
- Renamed to 'python-Sphinx', obsoletes 'python-sphinx'
- Update to version 1.0.7:
  * #347: Fix wrong generation of directives of static methods in
    autosummary.
  * #599: Import PIL as from PIL import Image.
  * #558: Fix longtables with captions in LaTeX output.
  * Make token references work as hyperlinks again in LaTeX output.
  * #572: Show warnings by default when reference labels cannot be
    found.
  * #536: Include line number when complaining about missing reference
    targets in nitpicky mode.
  * #590: Fix inline display of graphviz diagrams in LaTeX output.
  * #589: Build using app.build() in setup command.
  * Fix a bug in the inheritance diagram exception that caused base
    classes to be skipped if one of them is a builtin.
  * Fix general index links for C++ domain objects.
  * #332: Make admonition boundaries in LaTeX output visible.
  * #573: Fix KeyErrors occurring on rebuild after removing a file.
  * Fix a traceback when removing files with globbed toctrees.
  * If an autodoc object cannot be imported, always re-read the
    document containing the directive on next build.
  * If an autodoc object cannot be imported, show the full traceback
    of the import error.
  * Fix a bug where the removal of download files and images wasn't
    noticed.
  * #571: Implement ~ cross-reference prefix for the C domain.
  * Fix regression of LaTeX output with the fix of #556.
  * #568: Fix lookup of class attribute documentation on descriptors
    so that comment documentation now works.
  * Fix traceback with only directives preceded by targets.
  * Fix tracebacks occurring for duplicate C++ domain objects.
  * Fix JavaScript domain links to objects with $ in their name.
- Spec file cleanup:
  * Use fdupes and %%find_lang
  * Removed authors from description
  * Make doc package on require %%{version}, not %%{release}
* Wed Jan 12 2011 saschpe@suse.de
- Spec file cleanup
  * correct doc package group, no dupes
  * added rpmlintrc file
- Update to 1.0.6
  * #581: Fix traceback in Python domain for empty cross-reference
    targets.
  * #283: Fix literal block display issues on Chrome browsers.
  * #383, #148: Support sorting a limited range of accented
    characters in the general index and the glossary.
  * #570: Try decoding -D and -A command-line arguments with
    the locale's preferred encoding.
  * #528: Observe locale_dirs when looking for the JS
    translations file.
  * #574: Add special code for better support of Japanese documents
    in the LaTeX builder.
  * Regression of #77: If there is only one parameter given with
    :param: markup, the bullet list is now suppressed again.
  * #556: Fix missing paragraph breaks in LaTeX output in certain
    situations.
  * #567: Emit the autodoc-process-docstring event even for objects
    without a docstring so that it can add content.
  * #565: In the LaTeX builder, not only literal blocks require
    different table handling, but also quite a few other list-like
    block elements.
  * #515: Fix tracebacks in the viewcode extension for Python objects
    that do not have a valid signature.
  * Fix strange reportings of line numbers for warnings generated
    from autodoc-included docstrings, due to different behavior
    depending on docutils version.
  * Several fixes to the C++ domain.
* Mon Jan  3 2011 nix@opensuse.org
- Update to 1.0.5
* Wed Sep  8 2010 nix@opensuse.org
- Update to 1.0.3
* Mon Apr 26 2010 nix@opensuse.org
- Update to 0.6.5
* Tue Aug 11 2009 cfarrell@suse.de
- Update to 0.6.2 and split docs into separate package
* Fri Jun  5 2009 poeml@suse.de
- initial package (0.6.1)
